mirror of
https://github.com/NixOS/nixpkgs.git
synced 2026-07-06 17:13:24 -05:00
Merge branch 'staging-next' into staging
This commit is contained in:
commit
4d86f2810e
159 changed files with 1177 additions and 1012 deletions
|
|
@ -22,7 +22,7 @@ let
|
|||
pyqt6-sip
|
||||
sexpdata
|
||||
six
|
||||
xlib
|
||||
python-xlib
|
||||
];
|
||||
pythonEnv = python3.withPackages pythonPkgs;
|
||||
|
||||
|
|
|
|||
|
|
@ -6,8 +6,8 @@ vscode-utils.buildVscodeMarketplaceExtension {
|
|||
mktplcRef = {
|
||||
name = "vscode-wakatime";
|
||||
publisher = "WakaTime";
|
||||
version = "30.2.0";
|
||||
hash = "sha256-abXaPmdxBNsIEYvyuHu1fZGmCgv1Tpp9azj6O2zKXLs=";
|
||||
version = "30.2.1";
|
||||
hash = "sha256-FlH8uobKgUAAOr+6TCG9xYPiNN3FhlFp18dWKX8pFtE=";
|
||||
};
|
||||
|
||||
meta = {
|
||||
|
|
|
|||
|
|
@ -11,26 +11,26 @@ vscode-utils.buildVscodeMarketplaceExtension {
|
|||
sources = {
|
||||
"x86_64-linux" = {
|
||||
arch = "linux-x64";
|
||||
hash = "sha256-/D6d0qfgl8+cTEQ5ZeMjGgo1/Uzw5BxwBdM2m0fBjNU=";
|
||||
hash = "sha256-4GiTNT+UPdTth9VDhHTXfqhQ5gM6vfLAaU5Cy3VMTCI=";
|
||||
};
|
||||
"x86_64-darwin" = {
|
||||
arch = "darwin-x64";
|
||||
hash = "sha256-jIyFt1ZLNPS4DbQLnZJ3p30AnPJz3qNFDj/rL6EdnKw=";
|
||||
hash = "sha256-XJfDXWYpxYV5YHIBINqNJdyVho7Xd9OGMu11WE0LENM=";
|
||||
};
|
||||
"aarch64-linux" = {
|
||||
arch = "linux-arm64";
|
||||
hash = "sha256-6At96R7jSDAjvC7Bugpg4L/aHgHFQmBOdKcOTa3Y940=";
|
||||
hash = "sha256-QngCharrjiDKrY7RgWtKzIJxjXazuRvpuHVUAxknWfA=";
|
||||
};
|
||||
"aarch64-darwin" = {
|
||||
arch = "darwin-arm64";
|
||||
hash = "sha256-GB/QLRmtY/cVs4lrU8OFnWgztJSF8e07VADIra/et2s=";
|
||||
hash = "sha256-QPRZG7/Pjo9uboJl/RH0cdNf+zGM+ZRxdaMULxl34Jk=";
|
||||
};
|
||||
};
|
||||
in
|
||||
{
|
||||
name = "continue";
|
||||
publisher = "Continue";
|
||||
version = "1.2.22";
|
||||
version = "2.0.0";
|
||||
}
|
||||
// sources.${stdenv.system} or (throw "Unsupported system: ${stdenv.system}");
|
||||
nativeBuildInputs = lib.optionals stdenv.hostPlatform.isLinux [ autoPatchelfHook ];
|
||||
|
|
|
|||
|
|
@ -1174,8 +1174,8 @@ let
|
|||
mktplcRef = {
|
||||
publisher = "DanielSanMedium";
|
||||
name = "dscodegpt";
|
||||
version = "3.22.1";
|
||||
hash = "sha256-ln9DcfjW0QO7V6hF+QNqy+V13hbjWwhsisrgZPrk1R4=";
|
||||
version = "3.23.0";
|
||||
hash = "sha256-bbyFdb/hGPV93RJecdx6uozJIOaKitBBhwlI04s50NU=";
|
||||
};
|
||||
meta = {
|
||||
changelog = "https://marketplace.visualstudio.com/items/DanielSanMedium.dscodegpt/changelog";
|
||||
|
|
@ -1226,8 +1226,8 @@ let
|
|||
mktplcRef = {
|
||||
name = "databricks";
|
||||
publisher = "databricks";
|
||||
version = "2.11.0";
|
||||
hash = "sha256-9izhQvZmfUVeKS0H89XXkN1bNP4+AZyUuetfD0kRJ/c=";
|
||||
version = "2.11.1";
|
||||
hash = "sha256-QegVk1SJM/RegAVj7isgFcHwAJyQj9YDuP90u/7weSo=";
|
||||
};
|
||||
meta = {
|
||||
changelog = "https://marketplace.visualstudio.com/items/databricks.databricks/changelog";
|
||||
|
|
@ -1567,8 +1567,8 @@ let
|
|||
mktplcRef = {
|
||||
name = "elixir-ls";
|
||||
publisher = "JakeBecker";
|
||||
version = "0.30.0";
|
||||
hash = "sha256-vHD16liYmcWeiSP16QqKhPst8e7iT9wZ1vGT5gV6xoo=";
|
||||
version = "0.31.1";
|
||||
hash = "sha256-eF0OGWpiu5aDiFp8MFP7j2r2+3QCPb1q93gWg7L/Xzc=";
|
||||
};
|
||||
meta = {
|
||||
changelog = "https://marketplace.visualstudio.com/items/JakeBecker.elixir-ls/changelog";
|
||||
|
|
@ -1760,8 +1760,8 @@ let
|
|||
mktplcRef = {
|
||||
name = "foam-vscode";
|
||||
publisher = "foam";
|
||||
version = "0.43.1";
|
||||
hash = "sha256-rZjdBzqXpSG4aCMjRCmIrWtQdmmh7vEJQLIuH65Ewf0=";
|
||||
version = "0.44.1";
|
||||
hash = "sha256-OH4i4cGh/ivHQNAI55FHjM9ZjnhMaJSnsuQUnxub9/g=";
|
||||
};
|
||||
meta = {
|
||||
changelog = "https://marketplace.visualstudio.com/items/foam.foam-vscode/changelog";
|
||||
|
|
@ -2670,8 +2670,8 @@ let
|
|||
mktplcRef = {
|
||||
name = "language-julia";
|
||||
publisher = "julialang";
|
||||
version = "1.215.2";
|
||||
hash = "sha256-/3ULGcywO6SHvABRxaLXJQpjcrVs/vZxUGpG+NaSx3s=";
|
||||
version = "1.219.2";
|
||||
hash = "sha256-LQ7UL+/FtzRxn/M85fv3oh8g622KEPS35lque3kqby8=";
|
||||
};
|
||||
meta = {
|
||||
changelog = "https://marketplace.visualstudio.com/items/julialang.language-julia/changelog";
|
||||
|
|
@ -5482,8 +5482,8 @@ let
|
|||
mktplcRef = {
|
||||
name = "markdown-editor";
|
||||
publisher = "zaaack";
|
||||
version = "0.1.13";
|
||||
hash = "sha256-Si8/piNNktcyRY8o8o9my9sP9NEwrNuySVjlyadDjtU=";
|
||||
version = "0.1.15";
|
||||
hash = "sha256-wNGIps0Y/p5X/lutOh1gTPWXh0zpdTm5fFiccba6Pww=";
|
||||
};
|
||||
meta = {
|
||||
description = "Visual Studio Code extension for WYSIWYG markdown editing";
|
||||
|
|
|
|||
|
|
@ -833,13 +833,13 @@
|
|||
"vendorHash": "sha256-7mJ+BX7laBKsr4DX1keMXnGi79CZp8M1jD0COQ1lcmU="
|
||||
},
|
||||
"kreuzwerker_docker": {
|
||||
"hash": "sha256-wC0XYOGx3CBrXOkISmYFMMqcNijl3u2XZzrVOPF+EDo=",
|
||||
"hash": "sha256-prvQBNT2OhKmH0ABIs7saRqpURZwO+ntfIxoGe/KmMc=",
|
||||
"homepage": "https://registry.terraform.io/providers/kreuzwerker/docker",
|
||||
"owner": "kreuzwerker",
|
||||
"repo": "terraform-provider-docker",
|
||||
"rev": "v4.4.0",
|
||||
"rev": "v4.5.0",
|
||||
"spdx": "MPL-2.0",
|
||||
"vendorHash": "sha256-PIltVJ3o3ROFi1ensrJyFYEsCm6nEFXHkkTPU3ho+gU="
|
||||
"vendorHash": "sha256-EAv8EeNn0PJ3BElmg6sKkd/LXNe0lFjEIjHuZRG3CoQ="
|
||||
},
|
||||
"launchdarkly_launchdarkly": {
|
||||
"hash": "sha256-PgAK0BUTSyW4CXssQkENohnhtd2O5GPuFVvSDcHWjQ8=",
|
||||
|
|
|
|||
File diff suppressed because it is too large
Load diff
|
|
@ -40,7 +40,7 @@ rec {
|
|||
|
||||
dependencies = with python3Packages; [
|
||||
aw-client
|
||||
xlib
|
||||
python-xlib
|
||||
pynput
|
||||
];
|
||||
|
||||
|
|
@ -70,7 +70,7 @@ rec {
|
|||
|
||||
dependencies = with python3Packages; [
|
||||
aw-client
|
||||
xlib
|
||||
python-xlib
|
||||
];
|
||||
|
||||
pythonRelaxDeps = [
|
||||
|
|
|
|||
|
|
@ -110,7 +110,7 @@ effectiveStdenv.mkDerivation (finalAttrs: {
|
|||
]
|
||||
++ lib.optionals enableMpi [ mpi ]
|
||||
++ lib.optionals enableCuda [
|
||||
cudaPackages.cuda_cccl
|
||||
cudaPackages.cccl
|
||||
cudaPackages.cuda_cudart
|
||||
cudaPackages.libcufft
|
||||
cudaPackages.cuda_profiler_api
|
||||
|
|
|
|||
|
|
@ -67,7 +67,7 @@ python3Packages.buildPythonApplication (finalAttrs: {
|
|||
dependencies = with python3Packages; [
|
||||
dbus-python
|
||||
pyinotify
|
||||
xlib
|
||||
python-xlib
|
||||
pygobject3
|
||||
packaging
|
||||
standard-imghdr
|
||||
|
|
|
|||
|
|
@ -17,13 +17,13 @@
|
|||
|
||||
stdenvNoCC.mkDerivation (finalAttrs: {
|
||||
pname = "bashunit";
|
||||
version = "0.39.1";
|
||||
version = "0.40.0";
|
||||
|
||||
src = fetchFromGitHub {
|
||||
owner = "TypedDevs";
|
||||
repo = "bashunit";
|
||||
tag = finalAttrs.version;
|
||||
hash = "sha256-yMzi2SFEMSNNFztapWavMmbueWwVK0GWjyFR3cJZmTg=";
|
||||
hash = "sha256-7KH0zcoRPbY56h8FtJ0WbCqM2dSn/bklAPIthnktkpI=";
|
||||
forceFetchGit = true; # needed to include the tests directory for the check phase
|
||||
};
|
||||
|
||||
|
|
|
|||
|
|
@ -74,7 +74,7 @@ stdenv.mkDerivation (finalAttrs: {
|
|||
]
|
||||
++ lib.optionals cudaSupport [
|
||||
cudaPackages.cuda_cudart
|
||||
cudaPackages.cuda_cccl
|
||||
cudaPackages.cccl
|
||||
cudaPackages.libcublas
|
||||
];
|
||||
|
||||
|
|
|
|||
|
|
@ -26,18 +26,18 @@
|
|||
}:
|
||||
rustPlatform.buildRustPackage (finalAttrs: {
|
||||
pname = "codex";
|
||||
version = "0.139.0";
|
||||
version = "0.141.0";
|
||||
|
||||
src = fetchFromGitHub {
|
||||
owner = "openai";
|
||||
repo = "codex";
|
||||
tag = "rust-v${finalAttrs.version}";
|
||||
hash = "sha256-XjzlkBUkBey+P3tFLDYB3ae5oseUfW5tmzhLzqlqj2E=";
|
||||
hash = "sha256-1ZOaZlwAkH6DJpxlInfbXpaqmsbOIOGrFoj2dYehBMA=";
|
||||
};
|
||||
|
||||
sourceRoot = "${finalAttrs.src.name}/codex-rs";
|
||||
|
||||
cargoHash = "sha256-8mN4OTRJvt2mBYHQXZS55PSOChLqEIiXwPu2y+2MZ9o=";
|
||||
cargoHash = "sha256-bQPeRKTrNYeGCO20hpu+F37sScFOGr1EPOVf1E0FU+4=";
|
||||
|
||||
__structuredAttrs = true;
|
||||
|
||||
|
|
@ -60,7 +60,7 @@ rustPlatform.buildRustPackage (finalAttrs: {
|
|||
--replace-fail "cargo:rustc-link-lib=static=webrtc" "cargo:rustc-link-lib=dylib=webrtc"
|
||||
substituteInPlace Cargo.toml \
|
||||
--replace-fail 'lto = "thin"' "" \
|
||||
--replace-fail 'codegen-units = 1' ""
|
||||
--replace-fail 'codegen-units = 4' ""
|
||||
'';
|
||||
|
||||
nativeBuildInputs = [
|
||||
|
|
|
|||
|
|
@ -84,7 +84,7 @@ stdenv'.mkDerivation (finalAttrs: {
|
|||
mkl
|
||||
]
|
||||
++ lib.optionals withCUDA [
|
||||
cudaPackages.cuda_cccl # <nv/target> required by the fp16 headers in cudart
|
||||
cudaPackages.cccl # <nv/target> required by the fp16 headers in cudart
|
||||
cudaPackages.cuda_cudart
|
||||
cudaPackages.libcublas
|
||||
cudaPackages.libcurand
|
||||
|
|
|
|||
|
|
@ -1,5 +1,6 @@
|
|||
{
|
||||
lib,
|
||||
stdenv,
|
||||
buildGoModule,
|
||||
fetchFromGitHub,
|
||||
installShellFiles,
|
||||
|
|
@ -38,7 +39,7 @@ buildGoModule (finalAttrs: {
|
|||
makeWrapper
|
||||
];
|
||||
|
||||
buildInputs = lib.optionals libdrm.meta.available [
|
||||
buildInputs = lib.optionals (lib.meta.availableOn stdenv.hostPlatform libdrm) [
|
||||
libgbm
|
||||
playwright-driver.browsers
|
||||
];
|
||||
|
|
|
|||
|
|
@ -37,7 +37,7 @@ let
|
|||
# C.f. https://github.com/NVIDIA/DCGM/blob/7e1012302679e4bb7496483b32dcffb56e528c92/dcgmbuild/scripts/0080_cuda.sh#L24-L39
|
||||
getCudaPackages =
|
||||
p: with p; [
|
||||
cuda_cccl
|
||||
cccl
|
||||
cuda_cudart
|
||||
cuda_nvcc
|
||||
cuda_nvml_dev
|
||||
|
|
|
|||
|
|
@ -45,7 +45,7 @@ python3.pkgs.buildPythonApplication (finalAttrs: {
|
|||
requests
|
||||
pillow
|
||||
setuptools
|
||||
xlib
|
||||
python-xlib
|
||||
];
|
||||
postPatch = ''
|
||||
substituteInPlace discover_overlay/image_getter.py \
|
||||
|
|
|
|||
|
|
@ -76,7 +76,7 @@
|
|||
libcurand
|
||||
libcusolver
|
||||
cudnn
|
||||
cuda_cccl
|
||||
cccl
|
||||
]
|
||||
);
|
||||
|
||||
|
|
|
|||
|
|
@ -44,7 +44,7 @@ python3Packages.buildPythonApplication (finalAttrs: {
|
|||
pillow
|
||||
pygobject3
|
||||
pyxdg
|
||||
xlib
|
||||
python-xlib
|
||||
];
|
||||
|
||||
# no tests
|
||||
|
|
|
|||
|
|
@ -8,13 +8,13 @@
|
|||
|
||||
rustPlatform.buildRustPackage (finalAttrs: {
|
||||
pname = "dua";
|
||||
version = "2.35.0";
|
||||
version = "2.37.0";
|
||||
|
||||
src = fetchFromGitHub {
|
||||
owner = "Byron";
|
||||
repo = "dua-cli";
|
||||
tag = "v${finalAttrs.version}";
|
||||
hash = "sha256-dlm8jp7Bh0DgUN4ztalE6uPSzeJy+JDfai39xZKiptw=";
|
||||
hash = "sha256-vEc41MspD4Z8E8oFwPw52CiOguqgHQKUZ9Q8GooXPRA=";
|
||||
# Remove unicode file names which leads to different checksums on HFS+
|
||||
# vs. other filesystems because of unicode normalisation.
|
||||
postFetch = ''
|
||||
|
|
@ -22,7 +22,7 @@ rustPlatform.buildRustPackage (finalAttrs: {
|
|||
'';
|
||||
};
|
||||
|
||||
cargoHash = "sha256-620Emfkuzyc8/LVr8codB1/IAemxDBOnhS/rL6gR8R8=";
|
||||
cargoHash = "sha256-0ZdQ9ocl62SR74HlVqTYtGxAyf3HGUFCZinPbLBPPbw=";
|
||||
|
||||
checkFlags = [
|
||||
# Skip interactive tests
|
||||
|
|
|
|||
|
|
@ -19,6 +19,7 @@
|
|||
freetype,
|
||||
irrlicht,
|
||||
libevent,
|
||||
libdecor,
|
||||
libgit2,
|
||||
libGL,
|
||||
libGLU,
|
||||
|
|
@ -276,6 +277,7 @@ let
|
|||
--prefix PATH : ${lib.makeBinPath [ mono ]} \
|
||||
--prefix LD_LIBRARY_PATH : ${
|
||||
lib.makeLibraryPath [
|
||||
libdecor
|
||||
libGL
|
||||
libx11
|
||||
libxkbcommon
|
||||
|
|
|
|||
|
|
@ -12,11 +12,11 @@
|
|||
|
||||
stdenv.mkDerivation (finalAttrs: {
|
||||
pname = "eigenwallet";
|
||||
version = "4.4.1";
|
||||
version = "4.10.0";
|
||||
|
||||
src = fetchurl {
|
||||
url = "https://github.com/eigenwallet/core/releases/download/${finalAttrs.version}/eigenwallet_${finalAttrs.version}_amd64.deb";
|
||||
hash = "sha256-iwnDAF3iWol7wOc8HWVi/E8hgf0EcVE7RcUtm11JpOs=";
|
||||
hash = "sha256-hH4XdPQ5Q6mFbEcln/eA/ayxPjGbGSKYvTBa4qxD8Cc=";
|
||||
};
|
||||
|
||||
nativeBuildInputs = [
|
||||
|
|
|
|||
|
|
@ -31,10 +31,10 @@ let
|
|||
stdenv = if cudaSupport then backendStdenv else inputs.stdenv;
|
||||
|
||||
cudaComponents = with cudaPackages; [
|
||||
cccl
|
||||
cuda_cudart # cuda_runtime.h
|
||||
libcublas
|
||||
libcurand
|
||||
cuda_cccl
|
||||
|
||||
# cuda_profiler_api.h
|
||||
(cudaPackages.cuda_profiler_api or cudaPackages.cuda_nvprof)
|
||||
|
|
|
|||
|
|
@ -8,16 +8,16 @@
|
|||
|
||||
buildGoModule (finalAttrs: {
|
||||
pname = "files-cli";
|
||||
version = "2.15.335";
|
||||
version = "2.15.354";
|
||||
|
||||
src = fetchFromGitHub {
|
||||
repo = "files-cli";
|
||||
owner = "files-com";
|
||||
rev = "v${finalAttrs.version}";
|
||||
hash = "sha256-/X5h7umhwZQi65+MBTl4b9HKn28H+OTCgPV8UJJxV5o=";
|
||||
hash = "sha256-L1oF3KBB6q7YQvqfDq9jqY+onZrnIXECdD7RrdcYQtw=";
|
||||
};
|
||||
|
||||
vendorHash = "sha256-YRnw+1SgMSVq+PWzRfwy2UFAsGFii27vocntXFov8ys=";
|
||||
vendorHash = "sha256-RpihAKjYC6+TMrCZ4+ex6YBrXJwDrYeWp/a99NKCFQo=";
|
||||
|
||||
ldflags = [
|
||||
"-s"
|
||||
|
|
|
|||
|
|
@ -9,7 +9,7 @@
|
|||
|
||||
rustPlatform.buildRustPackage (finalAttrs: {
|
||||
pname = "function-runner";
|
||||
version = "9.1.2";
|
||||
version = "9.2.0";
|
||||
|
||||
__structuredAttrs = true;
|
||||
|
||||
|
|
@ -17,10 +17,10 @@ rustPlatform.buildRustPackage (finalAttrs: {
|
|||
owner = "Shopify";
|
||||
repo = "function-runner";
|
||||
tag = "v${finalAttrs.version}";
|
||||
hash = "sha256-KvReKvmF3i4zlfM8uj3KHamjfudcrhqrKGfK8O5tMpE=";
|
||||
hash = "sha256-+y4XQ4Oq4RdAMAD2mNtBAVb+8TqDbCNalXNo56UUOD4=";
|
||||
};
|
||||
|
||||
cargoHash = "sha256-gnEps/o+C8UpukO1oRF4qlhNsoAmyUmxMKGAgSykNY0=";
|
||||
cargoHash = "sha256-2XkfABzi55J/uO/2zO5QLLNx8pIb+YqowNPdJeMNdDI=";
|
||||
|
||||
nativeBuildInputs = [
|
||||
pkg-config
|
||||
|
|
|
|||
|
|
@ -47,9 +47,9 @@ python3Packages.buildPythonApplication (finalAttrs: {
|
|||
passthru.updateScript = nix-update-script { };
|
||||
|
||||
meta = {
|
||||
changelog = "https://github.com/mikf/gallery-dl/blob/v${finalAttrs.version}/CHANGELOG.md";
|
||||
changelog = "https://codeberg.org/mikf/gallery-dl/src/tag/v${finalAttrs.version}/CHANGELOG.md";
|
||||
description = "Command-line program to download image-galleries and -collections from several image hosting sites";
|
||||
homepage = "https://github.com/mikf/gallery-dl";
|
||||
homepage = "https://codeberg.org/mikf/gallery-dl";
|
||||
license = lib.licenses.gpl2Only;
|
||||
mainProgram = "gallery-dl";
|
||||
maintainers = with lib.maintainers; [
|
||||
|
|
|
|||
|
|
@ -71,7 +71,7 @@ stdenv.mkDerivation (finalAttrs: {
|
|||
++ lib.optionals cudaSupport (
|
||||
with cudaPackages;
|
||||
[
|
||||
cuda_cccl
|
||||
cccl
|
||||
cuda_cudart
|
||||
libcublas
|
||||
]
|
||||
|
|
|
|||
|
|
@ -12,7 +12,7 @@ let
|
|||
inherit (config) cudaSupport;
|
||||
inherit (cudaPackages)
|
||||
backendStdenv
|
||||
cuda_cccl
|
||||
cccl
|
||||
cuda_cudart
|
||||
cuda_nvcc
|
||||
libcublas
|
||||
|
|
@ -49,7 +49,7 @@ backendStdenv.mkDerivation {
|
|||
];
|
||||
|
||||
buildInputs = [
|
||||
cuda_cccl # <nv/target>
|
||||
cccl # <nv/target>
|
||||
cuda_cudart # driver_types.h
|
||||
cuda_nvcc # crt/host_defines.h
|
||||
libcublas # cublas_v2.h
|
||||
|
|
|
|||
93
pkgs/by-name/gr/graphify/package.nix
Normal file
93
pkgs/by-name/gr/graphify/package.nix
Normal file
|
|
@ -0,0 +1,93 @@
|
|||
{
|
||||
lib,
|
||||
python3Packages,
|
||||
fetchFromGitHub,
|
||||
python3,
|
||||
}:
|
||||
|
||||
python3Packages.buildPythonApplication rec {
|
||||
__structuredAttrs = true;
|
||||
pname = "graphify";
|
||||
version = "0.4.23";
|
||||
pyproject = true;
|
||||
|
||||
src = fetchFromGitHub {
|
||||
owner = "safishamsi";
|
||||
repo = "graphify";
|
||||
tag = "v${version}";
|
||||
hash = "sha256-QEzB1tFBqGhpmI7oudMRC1Ia0CDcm+GYt6AgxMA5zDo=";
|
||||
};
|
||||
|
||||
build-system = [
|
||||
python3.pkgs.setuptools
|
||||
];
|
||||
|
||||
dependencies =
|
||||
with python3.pkgs;
|
||||
[
|
||||
networkx
|
||||
tree-sitter
|
||||
]
|
||||
++ (with python3.pkgs.tree-sitter-grammars; [
|
||||
tree-sitter-c
|
||||
tree-sitter-c-sharp
|
||||
tree-sitter-cpp
|
||||
tree-sitter-elixir
|
||||
tree-sitter-go
|
||||
tree-sitter-java
|
||||
tree-sitter-javascript
|
||||
tree-sitter-julia
|
||||
tree-sitter-kotlin
|
||||
tree-sitter-lua
|
||||
tree-sitter-objc
|
||||
tree-sitter-php
|
||||
tree-sitter-powershell
|
||||
tree-sitter-python
|
||||
tree-sitter-ruby
|
||||
tree-sitter-rust
|
||||
tree-sitter-scala
|
||||
tree-sitter-swift
|
||||
tree-sitter-typescript
|
||||
tree-sitter-verilog
|
||||
tree-sitter-zig
|
||||
]);
|
||||
|
||||
optional-dependencies = with python3.pkgs; {
|
||||
leiden = [
|
||||
graspologic
|
||||
];
|
||||
mcp = [
|
||||
mcp
|
||||
];
|
||||
neo4j = [
|
||||
neo4j
|
||||
];
|
||||
office = [
|
||||
openpyxl
|
||||
python-docx
|
||||
];
|
||||
pdf = [
|
||||
html2text
|
||||
pypdf
|
||||
];
|
||||
svg = [
|
||||
matplotlib
|
||||
];
|
||||
video = [
|
||||
faster-whisper
|
||||
yt-dlp
|
||||
];
|
||||
watch = [
|
||||
watchdog
|
||||
];
|
||||
};
|
||||
|
||||
meta = {
|
||||
description = "AI coding assistant skill. Turn any folder of code, docs, papers, images, or videos into a queryable knowledge graph.";
|
||||
homepage = "https://github.com/safishamsi/graphify";
|
||||
changelog = "https://github.com/safishamsi/graphify/blob/${src.rev}/CHANGELOG.md";
|
||||
license = lib.licenses.mit;
|
||||
maintainers = with lib.maintainers; [ stunkymonkey ];
|
||||
mainProgram = "graphify";
|
||||
};
|
||||
}
|
||||
|
|
@ -52,7 +52,7 @@ python3Packages.buildPythonApplication (finalAttrs: {
|
|||
scrot
|
||||
slop
|
||||
xclip
|
||||
python3Packages.xlib
|
||||
python3Packages.python-xlib
|
||||
]
|
||||
++ (with python3Packages; [
|
||||
pillow
|
||||
|
|
|
|||
|
|
@ -25,7 +25,7 @@ let
|
|||
peewee
|
||||
pynvml
|
||||
pygobject3
|
||||
xlib
|
||||
python-xlib
|
||||
pyxdg
|
||||
requests
|
||||
rx
|
||||
|
|
|
|||
|
|
@ -88,7 +88,7 @@ python3Packages.buildPythonApplication (finalAttrs: {
|
|||
pyyaml
|
||||
rich
|
||||
setuptools
|
||||
xlib
|
||||
python-xlib
|
||||
pyroute2
|
||||
pygobject3
|
||||
dbus-python
|
||||
|
|
|
|||
|
|
@ -105,7 +105,7 @@ stdenv.mkDerivation (finalAttrs: {
|
|||
ps: with ps; [
|
||||
ewmh
|
||||
pytest
|
||||
xlib
|
||||
python-xlib
|
||||
]
|
||||
))
|
||||
xdotool
|
||||
|
|
|
|||
|
|
@ -49,7 +49,7 @@ python3Packages.buildPythonApplication {
|
|||
pycairo
|
||||
pygobject3
|
||||
six
|
||||
xlib
|
||||
python-xlib
|
||||
];
|
||||
|
||||
postPatch = ''
|
||||
|
|
|
|||
|
|
@ -6,10 +6,10 @@
|
|||
}:
|
||||
let
|
||||
pname = "hydralauncher";
|
||||
version = "3.9.9";
|
||||
version = "4.0.2";
|
||||
src = fetchurl {
|
||||
url = "https://github.com/hydralauncher/hydra/releases/download/v${version}/hydralauncher-${version}.AppImage";
|
||||
hash = "sha256-ZdrsEyJkenQbWTYEsgSaiMPx3JksHwjwti3HSb21iOw=";
|
||||
hash = "sha256-kb6tIP0xfbF23yg7aa9jmBFiApEPeKks2ZuWuEM4hGQ=";
|
||||
};
|
||||
|
||||
appimageContents = appimageTools.extractType2 { inherit pname src version; };
|
||||
|
|
|
|||
|
|
@ -23,7 +23,7 @@ python3Packages.buildPythonApplication {
|
|||
|
||||
propagatedBuildInputs = [
|
||||
python3Packages.i3ipc
|
||||
python3Packages.xlib
|
||||
python3Packages.python-xlib
|
||||
python3Packages.six
|
||||
];
|
||||
|
||||
|
|
|
|||
|
|
@ -22,7 +22,7 @@ python3.pkgs.buildPythonApplication (finalAttrs: {
|
|||
dependencies = with python3.pkgs; [
|
||||
dbus-fast
|
||||
pyudev
|
||||
xlib
|
||||
python-xlib
|
||||
];
|
||||
|
||||
postInstall = ''
|
||||
|
|
|
|||
|
|
@ -17,7 +17,7 @@
|
|||
withDocumentation ? stdenv.buildPlatform.canExecute stdenv.hostPlatform,
|
||||
}:
|
||||
let
|
||||
version = "1.51.0";
|
||||
version = "1.53.0";
|
||||
in
|
||||
rustPlatform.buildRustPackage {
|
||||
inherit version;
|
||||
|
|
@ -36,10 +36,10 @@ rustPlatform.buildRustPackage {
|
|||
owner = "casey";
|
||||
repo = "just";
|
||||
tag = version;
|
||||
hash = "sha256-urD9R/qn7rwtzaVP65angk7z4bwxlP3w5G5Aa5tVmuw=";
|
||||
hash = "sha256-+/G5fIPBl9NoDL0i9y67tjccte75yMT84pqsCWropws=";
|
||||
};
|
||||
|
||||
cargoHash = "sha256-war9yybsyfsm/wNlY+/fiN8pxxQwNLMogqe5u+jHNaw=";
|
||||
cargoHash = "sha256-Rwv10c487qOf6nH/Nj8rcfMLHRm8RaA5OYOh5p27rtM=";
|
||||
|
||||
nativeBuildInputs =
|
||||
lib.optionals (installShellCompletions || installManPages) [ installShellFiles ]
|
||||
|
|
|
|||
|
|
@ -78,7 +78,7 @@ stdenv'.mkDerivation rec {
|
|||
++ lib.optionals (backend == "cuda") (
|
||||
with cudaPackages;
|
||||
[
|
||||
cuda_cccl
|
||||
cccl
|
||||
cuda_cudart
|
||||
cuda_nvcc
|
||||
cudnn
|
||||
|
|
|
|||
|
|
@ -56,7 +56,7 @@ python3Packages.buildPythonApplication (finalAttrs: {
|
|||
pyxdg
|
||||
pycairo
|
||||
dbus-python
|
||||
xlib
|
||||
python-xlib
|
||||
];
|
||||
|
||||
patches = [
|
||||
|
|
|
|||
|
|
@ -28,7 +28,7 @@ let
|
|||
'';
|
||||
|
||||
propagatedBuildInputs = with python3Packages; [
|
||||
xlib
|
||||
python-xlib
|
||||
pygobject3.out
|
||||
dbus-python.out
|
||||
];
|
||||
|
|
|
|||
|
|
@ -74,7 +74,7 @@ effectiveStdenv.mkDerivation (finalAttrs: {
|
|||
cudaPackages.libcublas
|
||||
cudaPackages.cuda_nvcc
|
||||
cudaPackages.cuda_cudart
|
||||
cudaPackages.cuda_cccl
|
||||
cudaPackages.cccl
|
||||
]
|
||||
++ lib.optionals clblastSupport [
|
||||
clblast
|
||||
|
|
|
|||
|
|
@ -8,13 +8,13 @@
|
|||
}:
|
||||
|
||||
stdenv.mkDerivation (finalAttrs: {
|
||||
version = "4.8.1";
|
||||
version = "4.9.0";
|
||||
pname = "libre";
|
||||
src = fetchFromGitHub {
|
||||
owner = "baresip";
|
||||
repo = "re";
|
||||
rev = "v${finalAttrs.version}";
|
||||
sha256 = "sha256-fy7K7VE84E8JLWR9UZwHydL+I7NiAtlO8U4Gdr6m2KE=";
|
||||
sha256 = "sha256-0g3L+2PYLjnc2MyFhPX6exy+84oohP24As34oMBzO9k=";
|
||||
};
|
||||
|
||||
buildInputs = [
|
||||
|
|
|
|||
|
|
@ -59,7 +59,7 @@ let
|
|||
;
|
||||
|
||||
cudaBuildInputs = with cudaPackages; [
|
||||
cuda_cccl # <nv/target>
|
||||
cccl # <nv/target>
|
||||
|
||||
# A temporary hack for reducing the closure size, remove once cudaPackages
|
||||
# have stopped using lndir: https://github.com/NixOS/nixpkgs/issues/271792
|
||||
|
|
|
|||
|
|
@ -39,7 +39,7 @@ backendStdenv.mkDerivation (finalAttrs: {
|
|||
gmp
|
||||
cudaPackages.cuda_cudart
|
||||
cudaPackages.libcufft
|
||||
cudaPackages.cuda_cccl
|
||||
cudaPackages.cccl
|
||||
];
|
||||
|
||||
env = {
|
||||
|
|
|
|||
|
|
@ -77,7 +77,7 @@ let
|
|||
inherit (cudaPackages)
|
||||
libcublas
|
||||
cuda_nvcc
|
||||
cuda_cccl
|
||||
cccl
|
||||
cuda_cudart
|
||||
libcufft
|
||||
;
|
||||
|
|
@ -255,7 +255,7 @@ let
|
|||
buildInputs =
|
||||
[ ]
|
||||
++ lib.optionals with_cublas [
|
||||
cuda_cccl
|
||||
cccl
|
||||
cuda_cudart
|
||||
libcublas
|
||||
libcufft
|
||||
|
|
|
|||
|
|
@ -19,13 +19,13 @@
|
|||
|
||||
stdenv.mkDerivation (finalAttrs: {
|
||||
pname = "lua-language-server";
|
||||
version = "3.18.1";
|
||||
version = "3.18.2";
|
||||
|
||||
src = fetchFromGitHub {
|
||||
owner = "luals";
|
||||
repo = "lua-language-server";
|
||||
tag = finalAttrs.version;
|
||||
hash = "sha256-fD7qFY2xL86x/Ac03HkusvNh9Tn4LiqkJGGXNO0bPO8=";
|
||||
hash = "sha256-c8YxTNmvloN9oabdbl5ZKgXqhxeZ9eVBt3B0Q9wA/GQ=";
|
||||
fetchSubmodules = true;
|
||||
};
|
||||
|
||||
|
|
@ -137,6 +137,7 @@ stdenv.mkDerivation (finalAttrs: {
|
|||
license = lib.licenses.mit;
|
||||
maintainers = with lib.maintainers; [
|
||||
gepbird
|
||||
yvnth
|
||||
];
|
||||
mainProgram = "lua-language-server";
|
||||
platforms = lib.platforms.linux ++ lib.platforms.darwin;
|
||||
|
|
|
|||
|
|
@ -9,13 +9,13 @@
|
|||
|
||||
stdenv.mkDerivation (finalAttrs: {
|
||||
pname = "luau-lsp";
|
||||
version = "1.67.0";
|
||||
version = "1.68.1";
|
||||
|
||||
src = fetchFromGitHub {
|
||||
owner = "JohnnyMorganz";
|
||||
repo = "luau-lsp";
|
||||
tag = finalAttrs.version;
|
||||
hash = "sha256-J2/ARONeRZ5gy/3RE25GgPNahDUkrgbwQaQLU5AxVhk=";
|
||||
hash = "sha256-XxXAK/BaJcgel1vOATVbQVBxsxEYv9vr0w4JjmU64fM=";
|
||||
fetchSubmodules = true;
|
||||
};
|
||||
|
||||
|
|
|
|||
|
|
@ -44,7 +44,7 @@ effectiveStdenv.mkDerivation (finalAttrs: {
|
|||
++ lib.optionals cudaSupport (
|
||||
with cudaPackages;
|
||||
[
|
||||
cuda_cccl # cub/cub.cuh
|
||||
cccl # cub/cub.cuh
|
||||
libcublas # cublas_v2.h
|
||||
libcurand # curand.h
|
||||
libcusparse # cusparse.h
|
||||
|
|
|
|||
|
|
@ -45,7 +45,7 @@ stdenv.mkDerivation (finalAttrs: {
|
|||
++ lib.optionals cudaSupport (
|
||||
with cudaPackages;
|
||||
[
|
||||
cuda_cccl # cub/cub.cuh
|
||||
cccl # cub/cub.cuh
|
||||
libcublas # cublas_v2.h
|
||||
libcurand # curand.h
|
||||
libcusparse # cusparse.h
|
||||
|
|
|
|||
|
|
@ -207,7 +207,7 @@ stdenv.mkDerivation (finalAttrs: {
|
|||
++ lists.optionals cudaSupport (
|
||||
with cudaPackages;
|
||||
[
|
||||
cuda_cccl # <nv/target> and <cuda/std/type_traits>
|
||||
cccl # <nv/target> and <cuda/std/type_traits>
|
||||
cuda_cudart # cuda_runtime.h
|
||||
libcublas # cublas_v2.h
|
||||
libcusparse # cusparse.h
|
||||
|
|
|
|||
|
|
@ -38,17 +38,17 @@ let
|
|||
in
|
||||
rustPlatform.buildRustPackage (finalAttrs: {
|
||||
pname = "matrix-continuwuity";
|
||||
version = "0.5.9";
|
||||
version = "0.5.10";
|
||||
|
||||
src = fetchFromGitea {
|
||||
domain = "forgejo.ellis.link";
|
||||
owner = "continuwuation";
|
||||
repo = "continuwuity";
|
||||
tag = "v${finalAttrs.version}";
|
||||
hash = "sha256-4zs26kTqwkJV7x+Sm12LnR02bbyH0f6Itbz7bDKUyts=";
|
||||
hash = "sha256-oevEGYlAK/rMJhm200CkwerT5oVak8sJj0Fa6r6+J/Q=";
|
||||
};
|
||||
|
||||
cargoHash = "sha256-T11ESuNg3BS54LtNJfhOoIgiyVL7VsdP4OeDI2nVBIk=";
|
||||
cargoHash = "sha256-uvMiFURXxkLbbbwq4pG5hevsLZHQ1wVfTNvzQRTQWxE=";
|
||||
|
||||
nativeBuildInputs = [
|
||||
pkg-config
|
||||
|
|
|
|||
|
|
@ -129,7 +129,7 @@ rustPlatform.buildRustPackage (finalAttrs: {
|
|||
openssl
|
||||
]
|
||||
++ lib.optionals cudaSupport [
|
||||
cudaPackages.cuda_cccl
|
||||
cudaPackages.cccl
|
||||
cudaPackages.cuda_cudart
|
||||
cudaPackages.cuda_nvrtc
|
||||
cudaPackages.libcublas
|
||||
|
|
|
|||
|
|
@ -68,7 +68,7 @@ stdenv.mkDerivation (finalAttrs: {
|
|||
++ lib.optional enableMpi mpi
|
||||
++ lib.optionals cudaSupport [
|
||||
cudaPackages.cuda_cudart
|
||||
cudaPackages.cuda_cccl
|
||||
cudaPackages.cccl
|
||||
];
|
||||
|
||||
postInstall = ''
|
||||
|
|
|
|||
|
|
@ -83,7 +83,7 @@ rustPlatform.buildRustPackage (finalAttrs: {
|
|||
alsa-lib
|
||||
]
|
||||
++ lib.optionals config.cudaSupport [
|
||||
cudaPackages.cuda_cccl
|
||||
cudaPackages.cccl
|
||||
cudaPackages.cuda_cudart
|
||||
cudaPackages.cuda_nvrtc
|
||||
cudaPackages.libcublas
|
||||
|
|
|
|||
|
|
@ -29,13 +29,13 @@
|
|||
|
||||
stdenv.mkDerivation (finalAttrs: {
|
||||
pname = "nocturne";
|
||||
version = "1.2.2";
|
||||
version = "1.3.0";
|
||||
|
||||
src = fetchFromGitHub {
|
||||
owner = "Jeffser";
|
||||
repo = "Nocturne";
|
||||
tag = finalAttrs.version;
|
||||
hash = "sha256-2UtlOdxXFdWoGeEwb89qI5Xp8FES2I3Eno8DIbhkBhI=";
|
||||
hash = "sha256-z7E4PVSp7HDarnJeQFrJ/HznxUT+b6xTF0QTm5ffvTQ=";
|
||||
};
|
||||
|
||||
__structuredAttrs = true;
|
||||
|
|
|
|||
|
|
@ -82,7 +82,7 @@ let
|
|||
cudaLibs = [
|
||||
cudaPackages.cuda_cudart
|
||||
cudaPackages.libcublas
|
||||
cudaPackages.cuda_cccl
|
||||
cudaPackages.cccl
|
||||
];
|
||||
|
||||
vulkanLibs = [
|
||||
|
|
@ -102,7 +102,7 @@ let
|
|||
(lib.getBin (cudaPackages.cuda_nvcc.__spliced.buildHost or cudaPackages.cuda_nvcc))
|
||||
];
|
||||
|
||||
# cuda_cccl and cuda_cudart both have a LICENSE file in their output
|
||||
# cccl and cuda_cudart both have a LICENSE file in their output
|
||||
ignoreCollisions = true;
|
||||
};
|
||||
|
||||
|
|
|
|||
|
|
@ -205,7 +205,7 @@ effectiveStdenv.mkDerivation (finalAttrs: {
|
|||
++ lib.optionals cudaSupport (
|
||||
with cudaPackages;
|
||||
[
|
||||
cuda_cccl # cub/cub.cuh
|
||||
cccl # cub/cub.cuh
|
||||
libcublas # cublas_v2.h
|
||||
libcurand # curand.h
|
||||
libcusparse # cusparse.h
|
||||
|
|
|
|||
|
|
@ -48,7 +48,7 @@ stdenv.mkDerivation (finalAttrs: {
|
|||
|
||||
++ lib.optionals cudaSupport [
|
||||
cudaPackages.cuda_cudart
|
||||
cudaPackages.cuda_cccl
|
||||
cudaPackages.cccl
|
||||
];
|
||||
|
||||
cmakeFlags = [
|
||||
|
|
|
|||
|
|
@ -18,16 +18,16 @@
|
|||
}:
|
||||
rustPlatform.buildRustPackage (finalAttrs: {
|
||||
pname = "openmeters";
|
||||
version = "1.4.1";
|
||||
version = "1.7.0";
|
||||
|
||||
src = fetchFromGitHub {
|
||||
owner = "httpsworldview";
|
||||
repo = "openmeters";
|
||||
tag = "v${finalAttrs.version}";
|
||||
hash = "sha256-7B/S3B15xfjZEFvzISBvyIzszoIQ1CRXexPrsnFQ+YM=";
|
||||
hash = "sha256-s4GPRmYZmlMOTptUyGxMWc1Q/ZqCIlBd5mdMhC4oT4g=";
|
||||
};
|
||||
|
||||
cargoHash = "sha256-SiXv93Bir1Qq9T3blfcFdfDkmp00OIq9odxRrwcz/50=";
|
||||
cargoHash = "sha256-HlhZAmvEybKCipCX3Kd3v2GmF1QTB8Ja5gf6EqMk00Q=";
|
||||
|
||||
nativeBuildInputs = [
|
||||
pkg-config
|
||||
|
|
|
|||
|
|
@ -16,16 +16,16 @@
|
|||
let
|
||||
package = buildGoModule rec {
|
||||
pname = "opentofu";
|
||||
version = "1.12.1";
|
||||
version = "1.12.3";
|
||||
|
||||
src = fetchFromGitHub {
|
||||
owner = "opentofu";
|
||||
repo = "opentofu";
|
||||
tag = "v${version}";
|
||||
hash = "sha256-zD1oYHftqBrHGgF8QDHe+2VSfuKLi8ZhocD+0pL9mlI=";
|
||||
hash = "sha256-/Or8+rMsGbZ9aY/oSOqHH0vMFx9Pl0ZRa9KrVJ4X8Ls=";
|
||||
};
|
||||
|
||||
vendorHash = "sha256-fsAdTkCU1C6iCKMRc+NRKqfHJ5FczUISfO+g4wGnMJw=";
|
||||
vendorHash = "sha256-t4RVH90TSTwxNPR2tKQsk8qd6d2OP8MmjAjgIZx7OVY=";
|
||||
ldflags = [
|
||||
"-s"
|
||||
"-w"
|
||||
|
|
@ -36,6 +36,11 @@ let
|
|||
nativeBuildInputs = [ installShellFiles ];
|
||||
patches = [ ./provider-path-1_12.patch ];
|
||||
|
||||
postPatch = ''
|
||||
substituteInPlace go.mod \
|
||||
--replace-fail "go 1.26.4" "go 1.26.3"
|
||||
'';
|
||||
|
||||
passthru = {
|
||||
inherit plugins;
|
||||
tests = {
|
||||
|
|
|
|||
|
|
@ -29,7 +29,7 @@ python3Packages.buildPythonApplication (finalAttrs: {
|
|||
dbus-python
|
||||
pygobject3
|
||||
setproctitle
|
||||
xlib
|
||||
python-xlib
|
||||
])
|
||||
++ [ rofi ];
|
||||
|
||||
|
|
|
|||
|
|
@ -20,6 +20,7 @@
|
|||
systemd,
|
||||
xkeyboard-config,
|
||||
fontconfig,
|
||||
bashNonInteractive,
|
||||
systemdSupport ? lib.meta.availableOn stdenv.hostPlatform systemd,
|
||||
}:
|
||||
|
||||
|
|
@ -63,6 +64,7 @@ stdenv.mkDerivation (finalAttrs: {
|
|||
];
|
||||
|
||||
buildInputs = [
|
||||
bashNonInteractive
|
||||
gtk3
|
||||
libdrm
|
||||
libevdev
|
||||
|
|
|
|||
|
|
@ -7,17 +7,17 @@
|
|||
|
||||
buildNpmPackage (finalAttrs: {
|
||||
pname = "polonium";
|
||||
version = "1.1";
|
||||
version = "1.2.0";
|
||||
|
||||
src = fetchFromGitHub {
|
||||
owner = "zeroxoneafour";
|
||||
repo = "polonium";
|
||||
tag = "v${finalAttrs.version}";
|
||||
hash = "sha256-Rn6mfn1R7K36fcLfIlt89SSfDQ8r6Ck0lHcI0H/yGWI=";
|
||||
hash = "sha256-R50Br8GGVVkA/AtXvYazgBWSEax0KEvWwyFQv3zqWqU=";
|
||||
fetchSubmodules = true;
|
||||
};
|
||||
|
||||
npmDepsHash = "sha256-9j5UxPRfFnaqDAW877TDNHH4rmN5QvzsUSeRVCjIz3g=";
|
||||
npmDepsHash = "sha256-T8dW+ctRlN8fIJtPKy0niWcCuQTd3GV5MbmaZf8CqZk=";
|
||||
|
||||
__structuredAttrs = true;
|
||||
|
||||
|
|
|
|||
|
|
@ -15,7 +15,7 @@
|
|||
|
||||
stdenv.mkDerivation (finalAttrs: {
|
||||
pname = "proton-pass-cli";
|
||||
version = "2.1.3";
|
||||
version = "2.1.4";
|
||||
|
||||
__structuredAttrs = true;
|
||||
strictDeps = true;
|
||||
|
|
@ -57,19 +57,19 @@ stdenv.mkDerivation (finalAttrs: {
|
|||
sources = {
|
||||
"aarch64-darwin" = fetchurl {
|
||||
url = "https://proton.me/download/pass-cli/${finalAttrs.version}/pass-cli-macos-aarch64";
|
||||
hash = "sha256-pQihDrFG3w5LVbcAqT8MT7cJlhhcfIAgHwD/oyPLcEM=";
|
||||
hash = "sha256-i1eb9FLDRtpXNJpecsODnEZuBkF5uTg/SB7vv6imWkQ=";
|
||||
};
|
||||
"aarch64-linux" = fetchurl {
|
||||
url = "https://proton.me/download/pass-cli/${finalAttrs.version}/pass-cli-linux-aarch64";
|
||||
hash = "sha256-90rHOiapg8RfmLzD7kyqiaaiabnuQ60X95iR1sBV8gg=";
|
||||
hash = "sha256-YNVEVnJjeNgJF94OBdLhAml+4EO35CCjTVXIQ3ztifI=";
|
||||
};
|
||||
"x86_64-darwin" = fetchurl {
|
||||
url = "https://proton.me/download/pass-cli/${finalAttrs.version}/pass-cli-macos-x86_64";
|
||||
hash = "sha256-nC1OKcCqCQq972VWlkOCcv4zCYqVRFbg+X9yP1zwqMU=";
|
||||
hash = "sha256-7g9B06HCYCLj+Zr/byKA7D4PDhxEPCxYZSwm00VtwjU=";
|
||||
};
|
||||
"x86_64-linux" = fetchurl {
|
||||
url = "https://proton.me/download/pass-cli/${finalAttrs.version}/pass-cli-linux-x86_64";
|
||||
hash = "sha256-2/v/4cIHf50o2G6yxgCunbGgBMYE7CZwpA5iT2rpBHo=";
|
||||
hash = "sha256-jWN6x0PG7TlEfVbJyyijoV+uwhv/yr5EwhG8Pk/qtGA=";
|
||||
};
|
||||
};
|
||||
updateScript = writeShellScript "update-proton-pass-cli" ''
|
||||
|
|
|
|||
|
|
@ -1,15 +1,17 @@
|
|||
{
|
||||
lib,
|
||||
stdenv,
|
||||
fetchurl,
|
||||
fetchFromGitHub,
|
||||
}:
|
||||
|
||||
stdenv.mkDerivation (finalAttrs: {
|
||||
pname = "ripmime";
|
||||
version = "1.4.0.10";
|
||||
src = fetchurl {
|
||||
url = "https://pldaniels.com/ripmime/ripmime-${finalAttrs.version}.tar.gz";
|
||||
sha256 = "0sj06ibmlzy34n8v0mnlq2gwidy7n2aqcwgjh0xssz3vi941aqc9";
|
||||
version = "1.4.1.0";
|
||||
src = fetchFromGitHub {
|
||||
owner = "inflex";
|
||||
repo = "ripMIME";
|
||||
tag = "${finalAttrs.version}";
|
||||
hash = "sha256-D05cz10NTkgc+d3BzUvEkrmMGV/iw4r6m6tizc5TmaI=";
|
||||
};
|
||||
|
||||
preInstall = ''
|
||||
|
|
@ -32,10 +34,4 @@ stdenv.mkDerivation (finalAttrs: {
|
|||
mainProgram = "ripmime";
|
||||
license = lib.licenses.bsd3;
|
||||
};
|
||||
|
||||
passthru = {
|
||||
updateInfo = {
|
||||
downloadPage = "https://pldaniels.com/ripmime/";
|
||||
};
|
||||
};
|
||||
})
|
||||
|
|
|
|||
|
|
@ -38,7 +38,7 @@
|
|||
|
||||
rustPlatform.buildRustPackage (finalAttrs: {
|
||||
pname = "rustdesk";
|
||||
version = "1.4.7";
|
||||
version = "1.4.8";
|
||||
__structuredAttrs = true;
|
||||
|
||||
src = fetchFromGitHub {
|
||||
|
|
@ -46,10 +46,10 @@ rustPlatform.buildRustPackage (finalAttrs: {
|
|||
repo = "rustdesk";
|
||||
tag = finalAttrs.version;
|
||||
fetchSubmodules = true;
|
||||
hash = "sha256-k4hJjr6xN1EOPfxRoTZMAUXZCFrwod3c+jVtBbqqO0U=";
|
||||
hash = "sha256-SkCG/m/B0PhYHbCj5iMKMLaKwiBTx+Nk5Wv1mDRxTiM=";
|
||||
};
|
||||
|
||||
cargoHash = "sha256-vK0Z/BUlsmAIfbG8utHKNVDM3ZHPzHML+4l2tE6aU78=";
|
||||
cargoHash = "sha256-HAKcu4tuF6Og9jxYn8DWGQCc2Dr6taxXk5x8gFEzHJg=";
|
||||
|
||||
patches = [
|
||||
./make-build-reproducible.patch
|
||||
|
|
|
|||
|
|
@ -43,7 +43,7 @@ python3Packages.buildPythonApplication (finalAttrs: {
|
|||
dependencies = with python3Packages; [
|
||||
babel
|
||||
psutil
|
||||
xlib
|
||||
python-xlib
|
||||
pygobject3
|
||||
dbus-python
|
||||
packaging
|
||||
|
|
|
|||
|
|
@ -16,13 +16,13 @@ let
|
|||
in
|
||||
stdenvNoCC.mkDerivation {
|
||||
pname = "sddm-astronaut";
|
||||
version = "0-unstable-2026-05-12";
|
||||
version = "0-unstable-2026-06-17";
|
||||
|
||||
src = fetchFromGitHub {
|
||||
owner = "Keyitdev";
|
||||
repo = "sddm-astronaut-theme";
|
||||
rev = "8c85b9c8d00ce70e39320f77071dca2040544f19";
|
||||
hash = "sha256-+Z1igZ4BxRqXr/lxfHEr3I4n/sX8+AIwUr6JFO9yoWs=";
|
||||
rev = "cd46736b4135a71700d2225d60eb8e85917585eb";
|
||||
hash = "sha256-5ys3pP5GgkrIua/4II8KiQbWCwK8PZK6Sj3lCMe9q1c=";
|
||||
};
|
||||
|
||||
dontWrapQtApps = true;
|
||||
|
|
|
|||
|
|
@ -13,14 +13,14 @@ in
|
|||
python.pkgs.toPythonModule (
|
||||
python.pkgs.buildPythonApplication rec {
|
||||
pname = "searxng";
|
||||
version = "0-unstable-2026-05-16";
|
||||
version = "0-unstable-2026-06-20";
|
||||
pyproject = true;
|
||||
|
||||
src = fetchFromGitHub {
|
||||
owner = "searxng";
|
||||
repo = "searxng";
|
||||
rev = "dce3bb69bb45519bde01c610e09e45cd42fd896c";
|
||||
hash = "sha256-QU0LyK9avVT67soPDRpjpYAX0oWoC3zl7PnvHk/w8No=";
|
||||
rev = "fd42d4fda142901416038f4748ca8222d2ff7822";
|
||||
hash = "sha256-x88O+TuPi/BjZug0NAHLbD5jaVK4/NDoxhVkSvRXkA4=";
|
||||
};
|
||||
|
||||
nativeBuildInputs = with python.pkgs; [ pythonRelaxDepsHook ];
|
||||
|
|
|
|||
|
|
@ -19,13 +19,13 @@
|
|||
|
||||
stdenv.mkDerivation (finalAttrs: {
|
||||
pname = "silice";
|
||||
version = "0-unstable-2026-05-11";
|
||||
version = "0-unstable-2026-06-18";
|
||||
|
||||
src = fetchFromGitHub {
|
||||
owner = "sylefeb";
|
||||
repo = "silice";
|
||||
rev = "b8ac31f86176f209f591d15d56c701b4dcb65d35";
|
||||
hash = "sha256-xN0FfL6Fof9jS+nOz/B0rRErAdJonXKITuCSq32CU+Y=";
|
||||
rev = "620487d6b83035dd98299734c8c8fccf8f636005";
|
||||
hash = "sha256-NT19G5I5GVa9yjSj851TGGHJTkavQz4hmgPUE+MJe3c=";
|
||||
fetchSubmodules = true;
|
||||
};
|
||||
|
||||
|
|
|
|||
|
|
@ -56,7 +56,7 @@ python3Packages.buildPythonApplication (finalAttrs: {
|
|||
pyudev
|
||||
pyyaml
|
||||
typing-extensions
|
||||
xlib
|
||||
python-xlib
|
||||
];
|
||||
|
||||
nativeCheckInputs = with python3Packages; [
|
||||
|
|
|
|||
|
|
@ -19,13 +19,13 @@
|
|||
}:
|
||||
stdenv.mkDerivation (finalAttrs: {
|
||||
pname = "squid";
|
||||
version = "7.5";
|
||||
version = "7.6";
|
||||
|
||||
src = fetchurl {
|
||||
url = "https://github.com/squid-cache/squid/releases/download/SQUID_${
|
||||
builtins.replaceStrings [ "." ] [ "_" ] finalAttrs.version
|
||||
}/squid-${finalAttrs.version}.tar.xz";
|
||||
hash = "sha256-9gWJB9sBUNL10ihIK1qeVniSDPNorgzLzszrL/TDUQY=";
|
||||
hash = "sha256-hSF4/cN8WweGqTT8mQx9L//IKs8ZsihL4gm5ZDHSWZI=";
|
||||
};
|
||||
|
||||
nativeBuildInputs = [ pkg-config ];
|
||||
|
|
|
|||
|
|
@ -71,7 +71,7 @@ effectiveStdenv.mkDerivation (finalAttrs: {
|
|||
(optionals cudaSupport (
|
||||
with cudaPackages;
|
||||
[
|
||||
cuda_cccl
|
||||
cccl
|
||||
cuda_cudart
|
||||
libcublas
|
||||
]
|
||||
|
|
|
|||
|
|
@ -49,7 +49,7 @@ python3Packages.buildPythonApplication (finalAttrs: {
|
|||
pynput
|
||||
pyside6
|
||||
streamdeck
|
||||
xlib
|
||||
python-xlib
|
||||
importlib-metadata
|
||||
evdev
|
||||
]
|
||||
|
|
|
|||
|
|
@ -60,7 +60,7 @@ effectiveStdenv.mkDerivation rec {
|
|||
]
|
||||
++ lib.optionals enableCuda [
|
||||
cudaPackages.cuda_cudart
|
||||
cudaPackages.cuda_cccl
|
||||
cudaPackages.cccl
|
||||
cudaPackages.libcublas
|
||||
];
|
||||
|
||||
|
|
|
|||
|
|
@ -20,7 +20,7 @@ python3Packages.buildPythonApplication (finalAttrs: {
|
|||
i3ipc
|
||||
psutil
|
||||
tenacity
|
||||
xlib
|
||||
python-xlib
|
||||
];
|
||||
|
||||
installPhase = ''
|
||||
|
|
|
|||
|
|
@ -4,29 +4,31 @@
|
|||
fetchFromCodeberg,
|
||||
libxcursor,
|
||||
libx11,
|
||||
libxrender,
|
||||
installShellFiles,
|
||||
}:
|
||||
|
||||
stdenv.mkDerivation (finalAttrs: {
|
||||
pname = "sxcs";
|
||||
version = "1.1.0";
|
||||
version = "1.2.1";
|
||||
|
||||
src = fetchFromCodeberg {
|
||||
owner = "NRK";
|
||||
repo = "sxcs";
|
||||
tag = "v${finalAttrs.version}";
|
||||
hash = "sha256-rYmbbdZjeLCvGvNocI3+KVU2KBkYvRisayTyScTRay8=";
|
||||
hash = "sha256-7Dz14gARdiHZApT20PGS5pop327XROBeAXeKUeHo7iA=";
|
||||
};
|
||||
|
||||
buildInputs = [
|
||||
libx11
|
||||
libxcursor
|
||||
libxrender
|
||||
];
|
||||
nativeBuildInputs = [ installShellFiles ];
|
||||
|
||||
buildPhase = ''
|
||||
runHook preBuild
|
||||
${stdenv.cc.targetPrefix}cc -o sxcs sxcs.c -O3 -s -l X11 -l Xcursor
|
||||
${stdenv.cc.targetPrefix}cc -o sxcs sxcs.c -O3 -s -l X11 -l Xcursor -l Xrender
|
||||
runHook postBuild
|
||||
'';
|
||||
|
||||
|
|
|
|||
|
|
@ -18,7 +18,7 @@ let
|
|||
cuda-common-redist = with cudaPackages; [
|
||||
(lib.getDev cuda_cudart) # cuda_runtime.h
|
||||
(lib.getLib cuda_cudart)
|
||||
(lib.getDev cuda_cccl) # <nv/target>
|
||||
(lib.getDev cccl) # <nv/target>
|
||||
(lib.getInclude cuda_nvrtc) # nvrtc.h
|
||||
(lib.getLib cuda_nvrtc)
|
||||
(lib.getInclude libcublas) # cublas_v2.h
|
||||
|
|
|
|||
|
|
@ -1778,6 +1778,18 @@
|
|||
};
|
||||
};
|
||||
|
||||
objc = {
|
||||
version = "3.0.2";
|
||||
url = "github:tree-sitter-grammars/tree-sitter-objc";
|
||||
hash = "sha256-aK8Cf8F05NzlXnYS47jPjSyouaajsr1H+vRg2aXsPrs=";
|
||||
meta = {
|
||||
license = lib.licenses.mit;
|
||||
maintainers = with lib.maintainers; [
|
||||
stunkymonkey
|
||||
];
|
||||
};
|
||||
};
|
||||
|
||||
ocaml = {
|
||||
version = "0.24.2";
|
||||
url = "github:tree-sitter/tree-sitter-ocaml";
|
||||
|
|
|
|||
|
|
@ -52,7 +52,7 @@ lib.throwIf (enableDragAndDrop && !hasDndSupport)
|
|||
python3Packages.pynput
|
||||
python3Packages.pyside6
|
||||
python3Packages.requests
|
||||
python3Packages.xlib
|
||||
python3Packages.python-xlib
|
||||
kdePackages.qtbase
|
||||
kdePackages.qt6gtk2
|
||||
]);
|
||||
|
|
|
|||
|
|
@ -20,7 +20,7 @@ let
|
|||
inherit (lib.strings) concatStringsSep;
|
||||
|
||||
inherit (cudaPackages)
|
||||
cuda_cccl
|
||||
cccl
|
||||
cuda_cudart
|
||||
cuda_nvcc
|
||||
cuda_nvml_dev
|
||||
|
|
@ -77,7 +77,7 @@ effectiveStdenv.mkDerivation (finalAttrs: {
|
|||
ucx
|
||||
]
|
||||
++ optionals enableCuda [
|
||||
cuda_cccl
|
||||
cccl
|
||||
cuda_cudart
|
||||
cuda_nvml_dev
|
||||
nccl
|
||||
|
|
|
|||
|
|
@ -50,7 +50,7 @@ python3Packages.buildPythonPackage rec {
|
|||
[
|
||||
pyzstd
|
||||
urllib3
|
||||
xlib
|
||||
python-xlib
|
||||
]
|
||||
++ lib.optionals withTruststore [
|
||||
truststore
|
||||
|
|
|
|||
|
|
@ -7,11 +7,11 @@
|
|||
|
||||
stdenv.mkDerivation (finalAttrs: {
|
||||
pname = "wcslib";
|
||||
version = "8.8";
|
||||
version = "8.9";
|
||||
|
||||
src = fetchurl {
|
||||
url = "ftp://ftp.atnf.csiro.au/pub/software/wcslib/wcslib-${finalAttrs.version}.tar.bz2";
|
||||
hash = "sha256-3NW5UuaAFtDiRZ4fD5hmND54uTljXbZEKfz0eOHqS/w=";
|
||||
hash = "sha256-gqwJzlCRsL8Gzsj1ze7B2r4dBrpd+3/yvbDBaASIgHs=";
|
||||
};
|
||||
|
||||
# error: call to undeclared library function 'snprintf'
|
||||
|
|
|
|||
|
|
@ -58,7 +58,7 @@ let
|
|||
;
|
||||
|
||||
cudaBuildInputs = with cudaPackages; [
|
||||
cuda_cccl # <nv/target>
|
||||
cccl # <nv/target>
|
||||
|
||||
# A temporary hack for reducing the closure size, remove once cudaPackages
|
||||
# have stopped using lndir: https://github.com/NixOS/nixpkgs/issues/271792
|
||||
|
|
|
|||
|
|
@ -1,192 +1,71 @@
|
|||
{
|
||||
lib,
|
||||
stdenv,
|
||||
fetchFromGitHub,
|
||||
flutter341,
|
||||
keybinder3,
|
||||
nodejs,
|
||||
pnpm_9,
|
||||
fetchPnpmDeps,
|
||||
pnpmConfigHook,
|
||||
python3Packages,
|
||||
writableTmpDirAsHomeHook,
|
||||
callPackage,
|
||||
buildGoModule,
|
||||
pkg-config,
|
||||
replaceVars,
|
||||
|
||||
# build-time
|
||||
autoPatchelfHook,
|
||||
libxtst,
|
||||
copyDesktopItems,
|
||||
desktop-file-utils,
|
||||
makeDesktopItem,
|
||||
pkg-config,
|
||||
xdg-utils,
|
||||
|
||||
# run-time
|
||||
gtk3,
|
||||
libayatana-appindicator,
|
||||
libx11,
|
||||
libxkbcommon,
|
||||
xorgproto,
|
||||
libayatana-appindicator,
|
||||
gtk3,
|
||||
desktop-file-utils,
|
||||
xdg-utils,
|
||||
copyDesktopItems,
|
||||
makeDesktopItem,
|
||||
libxtst,
|
||||
nodejs,
|
||||
}:
|
||||
|
||||
let
|
||||
version = "2.0.2";
|
||||
buildGoModule (finalAttrs: {
|
||||
pname = "wox";
|
||||
version = "2.2.0";
|
||||
|
||||
src = fetchFromGitHub {
|
||||
owner = "Wox-launcher";
|
||||
repo = "Wox";
|
||||
tag = "v${version}";
|
||||
hash = "sha256-Qav2RhmhJQr2D1D3okshIrnnQuOh7V1gWbZwXR3LBAc=";
|
||||
tag = "v${finalAttrs.version}";
|
||||
hash = "sha256-FbOnENSko/BYtTI7z2Ep+IIYufgZpNWcz6d0mqhTL5g=";
|
||||
};
|
||||
|
||||
metaCommon = {
|
||||
description = "Cross-platform launcher that simply works";
|
||||
homepage = "https://github.com/Wox-launcher/Wox";
|
||||
license = with lib.licenses; [ gpl3Plus ];
|
||||
maintainers = [ ];
|
||||
};
|
||||
|
||||
ui-flutter = flutter341.buildFlutterApplication {
|
||||
pname = "wox-ui-flutter";
|
||||
inherit version src;
|
||||
|
||||
sourceRoot = "${src.name}/wox.ui.flutter/wox";
|
||||
|
||||
pubspecLock = lib.importJSON ./pubspec.lock.json;
|
||||
|
||||
postPatch = ''
|
||||
substituteInPlace linux/runner/my_application.cc \
|
||||
--replace-fail "X11/Xkeysym.h" "X11/keysym.h"
|
||||
'';
|
||||
|
||||
nativeBuildInputs = [ autoPatchelfHook ];
|
||||
|
||||
buildInputs = [
|
||||
keybinder3
|
||||
xorgproto
|
||||
libx11
|
||||
libxtst
|
||||
];
|
||||
|
||||
meta = metaCommon // {
|
||||
mainProgram = "wox";
|
||||
platforms = lib.platforms.linux;
|
||||
};
|
||||
};
|
||||
|
||||
plugin-host-nodejs = stdenv.mkDerivation (finalAttrs: {
|
||||
pname = "wox-plugin-host-nodejs";
|
||||
inherit version src;
|
||||
|
||||
sourceRoot = "${finalAttrs.src.name}/wox.plugin.host.nodejs";
|
||||
|
||||
nativeBuildInputs = [
|
||||
nodejs
|
||||
pnpmConfigHook
|
||||
pnpm_9
|
||||
];
|
||||
|
||||
pnpmDeps = fetchPnpmDeps {
|
||||
inherit (finalAttrs)
|
||||
pname
|
||||
version
|
||||
src
|
||||
sourceRoot
|
||||
;
|
||||
pnpm = pnpm_9;
|
||||
fetcherVersion = 3;
|
||||
hash = "sha256-cbuVQV8ih8rztERFLUHGnK63MBz8+QVmzeegYLDwcj4=";
|
||||
};
|
||||
|
||||
buildPhase = ''
|
||||
runHook preBuild
|
||||
|
||||
pnpm run build
|
||||
|
||||
runHook postBuild
|
||||
'';
|
||||
|
||||
installPhase = ''
|
||||
runHook preInstall
|
||||
|
||||
install -Dm644 dist/index.js $out/node-host.js
|
||||
|
||||
runHook postInstall
|
||||
'';
|
||||
|
||||
meta = metaCommon;
|
||||
});
|
||||
|
||||
plugin-python = python3Packages.buildPythonApplication {
|
||||
pname = "wox-plugin";
|
||||
inherit version src;
|
||||
pyproject = true;
|
||||
|
||||
sourceRoot = "${src.name}/wox.plugin.python";
|
||||
|
||||
build-system = with python3Packages; [ hatchling ];
|
||||
|
||||
meta = metaCommon;
|
||||
};
|
||||
|
||||
plugin-host-python = python3Packages.buildPythonApplication {
|
||||
pname = "wox-plugin-host-python";
|
||||
inherit version src;
|
||||
pyproject = true;
|
||||
|
||||
sourceRoot = "${src.name}/wox.plugin.host.python";
|
||||
|
||||
build-system = with python3Packages; [ hatchling ];
|
||||
|
||||
nativeBuildInputs = [ writableTmpDirAsHomeHook ];
|
||||
|
||||
buildInputs = with python3Packages; [
|
||||
loguru
|
||||
websockets
|
||||
plugin-python
|
||||
];
|
||||
|
||||
dependencies = with python3Packages; [
|
||||
loguru
|
||||
websockets
|
||||
plugin-python
|
||||
];
|
||||
|
||||
meta = metaCommon // {
|
||||
mainProgram = "run";
|
||||
};
|
||||
};
|
||||
in
|
||||
buildGoModule {
|
||||
pname = "wox";
|
||||
inherit version src;
|
||||
|
||||
sourceRoot = "${src.name}/wox.core";
|
||||
|
||||
postPatch = ''
|
||||
substituteInPlace plugin/host/host_python.go \
|
||||
--replace-fail 'n.findPythonPath(ctx), path.Join(util.GetLocation().GetHostDirectory(), "python-host.pyz")' '"env", "${plugin-host-python}/bin/run"'
|
||||
substituteInPlace plugin/host/host_nodejs.go \
|
||||
--replace-fail "/usr/bin/node" "${lib.getExe nodejs}"
|
||||
substituteInPlace util/deeplink.go \
|
||||
--replace-fail "update-desktop-database" "${desktop-file-utils}/bin/update-desktop-database" \
|
||||
--replace-fail "xdg-mime" "${xdg-utils}/bin/xdg-mime" \
|
||||
--replace-fail "Exec=%s" "Exec=wox"
|
||||
sed -i '/^ "path"$/d' plugin/host/host_python.go
|
||||
'';
|
||||
|
||||
vendorHash = "sha256-IDcIEZVCJp1ls5c2fblgX+I+MhfRDXqFbf0GhgcFiTo=";
|
||||
|
||||
sourceRoot = "${finalAttrs.src.name}/wox.core";
|
||||
|
||||
patches = [
|
||||
(replaceVars ./plugin-host-python.patch {
|
||||
plugin-host-python = "${finalAttrs.passthru.plugin-host-python}/bin/run";
|
||||
})
|
||||
(replaceVars ./plugin-host-nodejs.patch {
|
||||
nodejs-path = "${lib.getExe nodejs}";
|
||||
plugin-host-nodejs = "${finalAttrs.passthru.plugin-host-python}/node-host.js";
|
||||
})
|
||||
];
|
||||
|
||||
postPatch = ''
|
||||
substituteInPlace util/deeplink.go \
|
||||
--replace-fail "update-desktop-database" "${desktop-file-utils}/bin/update-desktop-database" \
|
||||
--replace-fail "xdg-mime" "${xdg-utils}/bin/xdg-mime"
|
||||
'';
|
||||
|
||||
proxyVendor = true;
|
||||
|
||||
nativeBuildInputs = [
|
||||
pkg-config
|
||||
autoPatchelfHook
|
||||
copyDesktopItems
|
||||
pkg-config
|
||||
];
|
||||
|
||||
buildInputs = [
|
||||
libx11
|
||||
libxtst
|
||||
libxkbcommon
|
||||
libayatana-appindicator
|
||||
gtk3
|
||||
libayatana-appindicator
|
||||
libx11
|
||||
libxkbcommon
|
||||
libxtst
|
||||
];
|
||||
|
||||
env.CGO_ENABLED = 1;
|
||||
|
|
@ -199,8 +78,8 @@ buildGoModule {
|
|||
|
||||
preBuild = ''
|
||||
mkdir -p resource/ui/flutter resource/hosts
|
||||
cp -r ${ui-flutter}/app/${ui-flutter.pname} resource/ui/flutter/wox
|
||||
cp ${plugin-host-nodejs}/node-host.js resource/hosts/node-host.js
|
||||
cp -r ${finalAttrs.passthru.ui-flutter}/app/${finalAttrs.passthru.ui-flutter.pname} resource/ui/flutter/wox
|
||||
cp ${finalAttrs.passthru.plugin-host-nodejs}/node-host.js resource/hosts/node-host.js
|
||||
'';
|
||||
|
||||
# XOpenDisplay failure!
|
||||
|
|
@ -220,8 +99,19 @@ buildGoModule {
|
|||
install -Dm644 ../assets/app.png $out/share/icons/wox.png
|
||||
'';
|
||||
|
||||
meta = metaCommon // {
|
||||
passthru = {
|
||||
plugin-host-nodejs = callPackage ./plugin-host-nodejs.nix { };
|
||||
plugin-host-python = callPackage ./plugin-host-python.nix { };
|
||||
ui-flutter = callPackage ./ui-flutter.nix { };
|
||||
};
|
||||
|
||||
meta = {
|
||||
description = "Cross-platform launcher that simply works";
|
||||
homepage = "https://github.com/Wox-launcher/Wox";
|
||||
changelog = "https://github.com/Wox-launcher/Wox/blob/${finalAttrs.src.rev}/CHANGELOG.md";
|
||||
mainProgram = "wox";
|
||||
platforms = lib.platforms.linux;
|
||||
license = with lib.licenses; [ gpl3Plus ];
|
||||
maintainers = with lib.maintainers; [ eljamm ];
|
||||
};
|
||||
}
|
||||
})
|
||||
|
|
|
|||
61
pkgs/by-name/wo/wox/plugin-host-nodejs.nix
Normal file
61
pkgs/by-name/wo/wox/plugin-host-nodejs.nix
Normal file
|
|
@ -0,0 +1,61 @@
|
|||
{
|
||||
lib,
|
||||
stdenv,
|
||||
wox,
|
||||
fetchPnpmDeps,
|
||||
nodejs,
|
||||
pnpmConfigHook,
|
||||
pnpm_11,
|
||||
}:
|
||||
stdenv.mkDerivation (finalAttrs: {
|
||||
pname = "wox-plugin-host-nodejs";
|
||||
inherit (wox)
|
||||
version
|
||||
src
|
||||
;
|
||||
|
||||
sourceRoot = "${finalAttrs.src.name}/wox.plugin.host.nodejs";
|
||||
|
||||
pnpmDeps = fetchPnpmDeps {
|
||||
inherit (finalAttrs)
|
||||
pname
|
||||
version
|
||||
src
|
||||
sourceRoot
|
||||
;
|
||||
pnpm = pnpm_11;
|
||||
fetcherVersion = 4;
|
||||
hash = "sha256-6zQDbNUxysqwrRaEMp8Sb5Vcf2HdkkdrdCpJwG8pHSs=";
|
||||
};
|
||||
|
||||
nativeBuildInputs = [
|
||||
nodejs
|
||||
pnpmConfigHook
|
||||
pnpm_11
|
||||
];
|
||||
|
||||
buildPhase = ''
|
||||
runHook preBuild
|
||||
|
||||
pnpm run build
|
||||
|
||||
runHook postBuild
|
||||
'';
|
||||
|
||||
installPhase = ''
|
||||
runHook preInstall
|
||||
|
||||
install -Dm644 dist/index.js $out/node-host.js
|
||||
|
||||
runHook postInstall
|
||||
'';
|
||||
|
||||
meta = {
|
||||
inherit (wox.meta)
|
||||
description
|
||||
homepage
|
||||
license
|
||||
maintainers
|
||||
;
|
||||
};
|
||||
})
|
||||
51
pkgs/by-name/wo/wox/plugin-host-nodejs.patch
Normal file
51
pkgs/by-name/wo/wox/plugin-host-nodejs.patch
Normal file
|
|
@ -0,0 +1,51 @@
|
|||
---
|
||||
plugin/host/host_nodejs.go | 12 +++---------
|
||||
1 file changed, 3 insertions(+), 9 deletions(-)
|
||||
|
||||
diff --git a/plugin/host/host_nodejs.go b/plugin/host/host_nodejs.go
|
||||
index c7554883..b81f693f 100644
|
||||
--- a/plugin/host/host_nodejs.go
|
||||
+++ b/plugin/host/host_nodejs.go
|
||||
@@ -6,7 +6,6 @@ import (
|
||||
"fmt"
|
||||
"os"
|
||||
"os/exec"
|
||||
- "path"
|
||||
"path/filepath"
|
||||
"runtime"
|
||||
"strings"
|
||||
@@ -39,12 +38,7 @@ func (n *NodejsHost) GetRuntime(ctx context.Context) plugin.Runtime {
|
||||
}
|
||||
|
||||
func (n *NodejsHost) Start(ctx context.Context) error {
|
||||
- nodePath, nodeErr := n.resolveNodejsPath(ctx)
|
||||
- if nodeErr != nil {
|
||||
- return nodeErr
|
||||
- }
|
||||
-
|
||||
- return n.websocketHost.StartHost(ctx, nodePath, path.Join(util.GetLocation().GetHostDirectory(), "node-host.js"), nil)
|
||||
+ return n.websocketHost.StartHost(ctx, "env", "@plugin-host-nodejs@", nil)
|
||||
}
|
||||
|
||||
// FindNodejsPath finds the best available Node.js interpreter path
|
||||
@@ -276,7 +270,7 @@ func collectNodejsPathsForDarwin() []string {
|
||||
paths := []string{
|
||||
"/opt/homebrew/bin/node",
|
||||
"/usr/local/bin/node",
|
||||
- "/usr/bin/node",
|
||||
+ "@nodejs-path@",
|
||||
"/usr/local/node",
|
||||
}
|
||||
paths = append(paths, collectNodejsPathsFromNvmUnix()...)
|
||||
@@ -287,7 +281,7 @@ func collectNodejsPathsForDarwin() []string {
|
||||
func collectNodejsPathsForLinux() []string {
|
||||
paths := []string{
|
||||
"/usr/local/bin/node",
|
||||
- "/usr/bin/node",
|
||||
+ "@nodejs-path@",
|
||||
"/usr/local/node",
|
||||
}
|
||||
paths = append(paths, collectNodejsPathsFromNvmUnix()...)
|
||||
--
|
||||
2.54.0
|
||||
|
||||
46
pkgs/by-name/wo/wox/plugin-host-python.nix
Normal file
46
pkgs/by-name/wo/wox/plugin-host-python.nix
Normal file
|
|
@ -0,0 +1,46 @@
|
|||
{
|
||||
python3Packages,
|
||||
callPackage,
|
||||
wox,
|
||||
writableTmpDirAsHomeHook,
|
||||
}:
|
||||
python3Packages.buildPythonApplication (finalAttrs: {
|
||||
pname = "wox-plugin-host-python";
|
||||
inherit (wox) version src;
|
||||
pyproject = true;
|
||||
|
||||
sourceRoot = "${finalAttrs.src.name}/wox.plugin.host.python";
|
||||
|
||||
build-system = with python3Packages; [
|
||||
hatchling
|
||||
];
|
||||
|
||||
nativeBuildInputs = [
|
||||
writableTmpDirAsHomeHook
|
||||
];
|
||||
|
||||
buildInputs = with python3Packages; [
|
||||
loguru
|
||||
websockets
|
||||
finalAttrs.passthru.plugin-python
|
||||
];
|
||||
|
||||
dependencies = with python3Packages; [
|
||||
loguru
|
||||
websockets
|
||||
finalAttrs.passthru.plugin-python
|
||||
];
|
||||
|
||||
passthru = {
|
||||
plugin-python = callPackage ./plugin-python.nix { };
|
||||
};
|
||||
|
||||
meta = {
|
||||
inherit (wox.meta)
|
||||
description
|
||||
homepage
|
||||
license
|
||||
maintainers
|
||||
;
|
||||
};
|
||||
})
|
||||
33
pkgs/by-name/wo/wox/plugin-host-python.patch
Normal file
33
pkgs/by-name/wo/wox/plugin-host-python.patch
Normal file
|
|
@ -0,0 +1,33 @@
|
|||
---
|
||||
plugin/host/host_python.go | 8 +-------
|
||||
1 file changed, 1 insertion(+), 7 deletions(-)
|
||||
|
||||
diff --git a/plugin/host/host_python.go b/plugin/host/host_python.go
|
||||
index 40e0195e..91a09501 100644
|
||||
--- a/plugin/host/host_python.go
|
||||
+++ b/plugin/host/host_python.go
|
||||
@@ -6,7 +6,6 @@ import (
|
||||
"fmt"
|
||||
"os"
|
||||
"os/exec"
|
||||
- "path"
|
||||
"path/filepath"
|
||||
"runtime"
|
||||
"strings"
|
||||
@@ -39,12 +38,7 @@ func (n *PythonHost) GetRuntime(ctx context.Context) plugin.Runtime {
|
||||
}
|
||||
|
||||
func (n *PythonHost) Start(ctx context.Context) error {
|
||||
- pythonPath, pythonErr := n.resolvePythonPath(ctx)
|
||||
- if pythonErr != nil {
|
||||
- return pythonErr
|
||||
- }
|
||||
-
|
||||
- return n.websocketHost.StartHost(ctx, pythonPath, path.Join(util.GetLocation().GetHostDirectory(), "python-host.pyz"), []string{"SHIV_ROOT=" + util.GetLocation().GetCacheDirectory()})
|
||||
+ return n.websocketHost.StartHost(ctx, "env", "@plugin-host-python@", []string{"SHIV_ROOT=" + util.GetLocation().GetCacheDirectory()})
|
||||
}
|
||||
|
||||
// FindPythonPath finds the best available Python interpreter path
|
||||
--
|
||||
2.54.0
|
||||
|
||||
27
pkgs/by-name/wo/wox/plugin-python.nix
Normal file
27
pkgs/by-name/wo/wox/plugin-python.nix
Normal file
|
|
@ -0,0 +1,27 @@
|
|||
{
|
||||
python3Packages,
|
||||
wox,
|
||||
}:
|
||||
python3Packages.buildPythonApplication (finalAttrs: {
|
||||
pname = "wox-plugin";
|
||||
inherit (wox)
|
||||
version
|
||||
src
|
||||
;
|
||||
pyproject = true;
|
||||
|
||||
sourceRoot = "${finalAttrs.src.name}/wox.plugin.python";
|
||||
|
||||
build-system = with python3Packages; [
|
||||
hatchling
|
||||
];
|
||||
|
||||
meta = {
|
||||
inherit (wox.meta)
|
||||
description
|
||||
homepage
|
||||
license
|
||||
maintainers
|
||||
;
|
||||
};
|
||||
})
|
||||
|
|
@ -1,7 +1,7 @@
|
|||
{
|
||||
"packages": {
|
||||
"archive": {
|
||||
"dependency": "transitive",
|
||||
"dependency": "direct main",
|
||||
"description": {
|
||||
"name": "archive",
|
||||
"sha256": "2fde1607386ab523f7a36bb3e7edb43bd58e6edaf2ffb29d8a6d578b297fdbbd",
|
||||
|
|
@ -54,11 +54,11 @@
|
|||
"dependency": "transitive",
|
||||
"description": {
|
||||
"name": "characters",
|
||||
"sha256": "f71061c654a3380576a52b451dd5532377954cf9dbd272a78fc8479606670803",
|
||||
"sha256": "faf38497bda5ead2a8c7615f4f7939df04333478bf32e4173fcb06d428b5716b",
|
||||
"url": "https://pub.dev"
|
||||
},
|
||||
"source": "hosted",
|
||||
"version": "1.4.0"
|
||||
"version": "1.4.1"
|
||||
},
|
||||
"charcode": {
|
||||
"dependency": "transitive",
|
||||
|
|
@ -100,16 +100,6 @@
|
|||
"source": "hosted",
|
||||
"version": "1.19.1"
|
||||
},
|
||||
"convert": {
|
||||
"dependency": "transitive",
|
||||
"description": {
|
||||
"name": "convert",
|
||||
"sha256": "b30acd5944035672bc15c6b7a8b47d773e41e2f17de064350988c5d02adb1c68",
|
||||
"url": "https://pub.dev"
|
||||
},
|
||||
"source": "hosted",
|
||||
"version": "3.1.2"
|
||||
},
|
||||
"cross_file": {
|
||||
"dependency": "transitive",
|
||||
"description": {
|
||||
|
|
@ -150,26 +140,6 @@
|
|||
"source": "hosted",
|
||||
"version": "0.7.0"
|
||||
},
|
||||
"device_info_plus": {
|
||||
"dependency": "transitive",
|
||||
"description": {
|
||||
"name": "device_info_plus",
|
||||
"sha256": "72d146c6d7098689ff5c5f66bcf593ac11efc530095385356e131070333e64da",
|
||||
"url": "https://pub.dev"
|
||||
},
|
||||
"source": "hosted",
|
||||
"version": "11.3.0"
|
||||
},
|
||||
"device_info_plus_platform_interface": {
|
||||
"dependency": "transitive",
|
||||
"description": {
|
||||
"name": "device_info_plus_platform_interface",
|
||||
"sha256": "e1ea89119e34903dca74b883d0dd78eb762814f97fb6c76f35e9ff74d261a18f",
|
||||
"url": "https://pub.dev"
|
||||
},
|
||||
"source": "hosted",
|
||||
"version": "7.0.3"
|
||||
},
|
||||
"dio": {
|
||||
"dependency": "direct main",
|
||||
"description": {
|
||||
|
|
@ -213,11 +183,12 @@
|
|||
"extended_text_field": {
|
||||
"dependency": "direct main",
|
||||
"description": {
|
||||
"name": "extended_text_field",
|
||||
"sha256": "3996195c117c6beb734026a7bc0ba80d7e4e84e4edd4728caa544d8209ab4d7d",
|
||||
"url": "https://pub.dev"
|
||||
"path": ".",
|
||||
"ref": "b9b2c8faff334c794ce70e5b6a30bda43e407009",
|
||||
"resolved-ref": "b9b2c8faff334c794ce70e5b6a30bda43e407009",
|
||||
"url": "https://github.com/qianlifeng/extended_text_field.git"
|
||||
},
|
||||
"source": "hosted",
|
||||
"source": "git",
|
||||
"version": "16.0.2"
|
||||
},
|
||||
"extended_text_library": {
|
||||
|
|
@ -286,16 +257,6 @@
|
|||
"source": "sdk",
|
||||
"version": "0.0.0"
|
||||
},
|
||||
"flutter_acrylic": {
|
||||
"dependency": "direct main",
|
||||
"description": {
|
||||
"name": "flutter_acrylic",
|
||||
"sha256": "b3996dbde5abf5823cc9ead4cf2e5267c3181f15585fe47ce4dc4472e7ec827a",
|
||||
"url": "https://pub.dev"
|
||||
},
|
||||
"source": "hosted",
|
||||
"version": "1.1.4"
|
||||
},
|
||||
"flutter_code_editor": {
|
||||
"dependency": "direct main",
|
||||
"description": {
|
||||
|
|
@ -414,11 +375,11 @@
|
|||
"dependency": "direct main",
|
||||
"description": {
|
||||
"name": "gpt_markdown",
|
||||
"sha256": "9b88dfaffea644070b648c204ca4a55745a49f4ad0b58ed0ab70913ad593c7a1",
|
||||
"sha256": "c14c2a4599a67df5b6a984808cbb7631b8d15c91984ffdd7998597b93a6ff136",
|
||||
"url": "https://pub.dev"
|
||||
},
|
||||
"source": "hosted",
|
||||
"version": "1.1.5"
|
||||
"version": "1.1.7"
|
||||
},
|
||||
"highlight": {
|
||||
"dependency": "direct main",
|
||||
|
|
@ -440,56 +401,6 @@
|
|||
"source": "hosted",
|
||||
"version": "2.2.3"
|
||||
},
|
||||
"hotkey_manager": {
|
||||
"dependency": "direct main",
|
||||
"description": {
|
||||
"name": "hotkey_manager",
|
||||
"sha256": "06f0655b76c8dd322fb7101dc615afbdbf39c3d3414df9e059c33892104479cd",
|
||||
"url": "https://pub.dev"
|
||||
},
|
||||
"source": "hosted",
|
||||
"version": "0.2.3"
|
||||
},
|
||||
"hotkey_manager_linux": {
|
||||
"dependency": "transitive",
|
||||
"description": {
|
||||
"name": "hotkey_manager_linux",
|
||||
"sha256": "83676bda8210a3377bc6f1977f193bc1dbdd4c46f1bdd02875f44b6eff9a8473",
|
||||
"url": "https://pub.dev"
|
||||
},
|
||||
"source": "hosted",
|
||||
"version": "0.2.0"
|
||||
},
|
||||
"hotkey_manager_macos": {
|
||||
"dependency": "transitive",
|
||||
"description": {
|
||||
"name": "hotkey_manager_macos",
|
||||
"sha256": "03b5967e64357b9ac05188ea4a5df6fe4ed4205762cb80aaccf8916ee1713c96",
|
||||
"url": "https://pub.dev"
|
||||
},
|
||||
"source": "hosted",
|
||||
"version": "0.2.0"
|
||||
},
|
||||
"hotkey_manager_platform_interface": {
|
||||
"dependency": "transitive",
|
||||
"description": {
|
||||
"name": "hotkey_manager_platform_interface",
|
||||
"sha256": "98ffca25b8cc9081552902747b2942e3bc37855389a4218c9d50ca316b653b13",
|
||||
"url": "https://pub.dev"
|
||||
},
|
||||
"source": "hosted",
|
||||
"version": "0.2.0"
|
||||
},
|
||||
"hotkey_manager_windows": {
|
||||
"dependency": "transitive",
|
||||
"description": {
|
||||
"name": "hotkey_manager_windows",
|
||||
"sha256": "0d03ced9fe563ed0b68f0a0e1b22c9ffe26eb8053cb960e401f68a4f070e0117",
|
||||
"url": "https://pub.dev"
|
||||
},
|
||||
"source": "hosted",
|
||||
"version": "0.2.0"
|
||||
},
|
||||
"http": {
|
||||
"dependency": "transitive",
|
||||
"description": {
|
||||
|
|
@ -516,26 +427,6 @@
|
|||
"source": "sdk",
|
||||
"version": "0.0.0"
|
||||
},
|
||||
"intl": {
|
||||
"dependency": "transitive",
|
||||
"description": {
|
||||
"name": "intl",
|
||||
"sha256": "3df61194eb431efc39c4ceba583b95633a403f46c9fd341e550ce0bfa50e9aa5",
|
||||
"url": "https://pub.dev"
|
||||
},
|
||||
"source": "hosted",
|
||||
"version": "0.20.2"
|
||||
},
|
||||
"json_annotation": {
|
||||
"dependency": "transitive",
|
||||
"description": {
|
||||
"name": "json_annotation",
|
||||
"sha256": "1ce844379ca14835a50d2f019a3099f419082cfdd231cd86a142af94dd5c6bb1",
|
||||
"url": "https://pub.dev"
|
||||
},
|
||||
"source": "hosted",
|
||||
"version": "4.9.0"
|
||||
},
|
||||
"leak_tracker": {
|
||||
"dependency": "transitive",
|
||||
"description": {
|
||||
|
|
@ -616,35 +507,25 @@
|
|||
"source": "hosted",
|
||||
"version": "2.0.3"
|
||||
},
|
||||
"macos_window_utils": {
|
||||
"dependency": "transitive",
|
||||
"description": {
|
||||
"name": "macos_window_utils",
|
||||
"sha256": "d4df3501fd32ac0d2d7590cb6a8e4758337d061c8fa0db816fdd636be63a8438",
|
||||
"url": "https://pub.dev"
|
||||
},
|
||||
"source": "hosted",
|
||||
"version": "1.9.0"
|
||||
},
|
||||
"matcher": {
|
||||
"dependency": "transitive",
|
||||
"description": {
|
||||
"name": "matcher",
|
||||
"sha256": "dc58c723c3c24bf8d3e2d3ad3f2f9d7bd9cf43ec6feaa64181775e60190153f2",
|
||||
"sha256": "dc0b7dc7651697ea4ff3e69ef44b0407ea32c487a39fff6a4004fa585e901861",
|
||||
"url": "https://pub.dev"
|
||||
},
|
||||
"source": "hosted",
|
||||
"version": "0.12.17"
|
||||
"version": "0.12.19"
|
||||
},
|
||||
"material_color_utilities": {
|
||||
"dependency": "transitive",
|
||||
"description": {
|
||||
"name": "material_color_utilities",
|
||||
"sha256": "f7142bb1154231d7ea5f96bc7bde4bda2a0945d2806bb11670e30b850d56bdec",
|
||||
"sha256": "9c337007e82b1889149c82ed242ed1cb24a66044e30979c44912381e9be4c48b",
|
||||
"url": "https://pub.dev"
|
||||
},
|
||||
"source": "hosted",
|
||||
"version": "0.11.1"
|
||||
"version": "0.13.0"
|
||||
},
|
||||
"math_expressions": {
|
||||
"dependency": "direct main",
|
||||
|
|
@ -660,11 +541,11 @@
|
|||
"dependency": "transitive",
|
||||
"description": {
|
||||
"name": "meta",
|
||||
"sha256": "e3641ec5d63ebf0d9b41bd43201a66e3fc79a65db5f61fc181f04cd27aab950c",
|
||||
"sha256": "1741988757a65eb6b36abe716829688cf01910bbf91c34354ff7ec1c3de2b349",
|
||||
"url": "https://pub.dev"
|
||||
},
|
||||
"source": "hosted",
|
||||
"version": "1.16.0"
|
||||
"version": "1.18.0"
|
||||
},
|
||||
"mime": {
|
||||
"dependency": "transitive",
|
||||
|
|
@ -962,96 +843,6 @@
|
|||
"source": "hosted",
|
||||
"version": "0.3.1"
|
||||
},
|
||||
"syncfusion_flutter_core": {
|
||||
"dependency": "transitive",
|
||||
"description": {
|
||||
"name": "syncfusion_flutter_core",
|
||||
"sha256": "e1fdfcc3ed7e1f040ba95838780b2eb1857e3e5eccb817fbe94ea2b09c35eac4",
|
||||
"url": "https://pub.dev"
|
||||
},
|
||||
"source": "hosted",
|
||||
"version": "31.2.18"
|
||||
},
|
||||
"syncfusion_flutter_pdf": {
|
||||
"dependency": "transitive",
|
||||
"description": {
|
||||
"name": "syncfusion_flutter_pdf",
|
||||
"sha256": "4077abff3d3dcae757317c0a85cb607b98cc6ea8f3b47c7d8488d4144ef01a9f",
|
||||
"url": "https://pub.dev"
|
||||
},
|
||||
"source": "hosted",
|
||||
"version": "31.2.18"
|
||||
},
|
||||
"syncfusion_flutter_pdfviewer": {
|
||||
"dependency": "direct main",
|
||||
"description": {
|
||||
"name": "syncfusion_flutter_pdfviewer",
|
||||
"sha256": "4bb3cdff34fe937430fdd0b5d6488f6a68efa8cfe08c73cc4b19d2a879dde057",
|
||||
"url": "https://pub.dev"
|
||||
},
|
||||
"source": "hosted",
|
||||
"version": "31.1.21"
|
||||
},
|
||||
"syncfusion_flutter_signaturepad": {
|
||||
"dependency": "transitive",
|
||||
"description": {
|
||||
"name": "syncfusion_flutter_signaturepad",
|
||||
"sha256": "56c35321879b900f59a91e0758af7ca66973447bfdaeb643fe1da0084cbc5b22",
|
||||
"url": "https://pub.dev"
|
||||
},
|
||||
"source": "hosted",
|
||||
"version": "31.2.18"
|
||||
},
|
||||
"syncfusion_pdfviewer_linux": {
|
||||
"dependency": "transitive",
|
||||
"description": {
|
||||
"name": "syncfusion_pdfviewer_linux",
|
||||
"sha256": "bae7feb109b38ecf9f8be99bd032503adf98e56da048307a17af8515d0f9d2ed",
|
||||
"url": "https://pub.dev"
|
||||
},
|
||||
"source": "hosted",
|
||||
"version": "31.2.18"
|
||||
},
|
||||
"syncfusion_pdfviewer_macos": {
|
||||
"dependency": "transitive",
|
||||
"description": {
|
||||
"name": "syncfusion_pdfviewer_macos",
|
||||
"sha256": "5c02ead2a430cd3f203639ede38ce2e06fb6c8aab6791b0d15c01436f882f482",
|
||||
"url": "https://pub.dev"
|
||||
},
|
||||
"source": "hosted",
|
||||
"version": "31.2.18"
|
||||
},
|
||||
"syncfusion_pdfviewer_platform_interface": {
|
||||
"dependency": "transitive",
|
||||
"description": {
|
||||
"name": "syncfusion_pdfviewer_platform_interface",
|
||||
"sha256": "65641e064385ac65253930ec96a6edc2eea781c9e15bf3d5fa15e459037817e7",
|
||||
"url": "https://pub.dev"
|
||||
},
|
||||
"source": "hosted",
|
||||
"version": "31.2.18"
|
||||
},
|
||||
"syncfusion_pdfviewer_web": {
|
||||
"dependency": "transitive",
|
||||
"description": {
|
||||
"name": "syncfusion_pdfviewer_web",
|
||||
"sha256": "c55201d9eda49f543b9ad21f539b0f5fbe45ca1a3b30081ee471eb4dff7132f4",
|
||||
"url": "https://pub.dev"
|
||||
},
|
||||
"source": "hosted",
|
||||
"version": "31.2.18"
|
||||
},
|
||||
"syncfusion_pdfviewer_windows": {
|
||||
"dependency": "transitive",
|
||||
"description": {
|
||||
"name": "syncfusion_pdfviewer_windows",
|
||||
"sha256": "1b706e58a95c794687d037e055cf0580370ceee27a59a8cd4e14368534161af8",
|
||||
"url": "https://pub.dev"
|
||||
},
|
||||
"source": "hosted",
|
||||
"version": "31.2.18"
|
||||
},
|
||||
"term_glyph": {
|
||||
"dependency": "transitive",
|
||||
"description": {
|
||||
|
|
@ -1066,11 +857,11 @@
|
|||
"dependency": "transitive",
|
||||
"description": {
|
||||
"name": "test_api",
|
||||
"sha256": "522f00f556e73044315fa4585ec3270f1808a4b186c936e612cab0b565ff1e00",
|
||||
"sha256": "949a932224383300f01be9221c39180316445ecb8e7547f70a41a35bf421fb9e",
|
||||
"url": "https://pub.dev"
|
||||
},
|
||||
"source": "hosted",
|
||||
"version": "0.7.6"
|
||||
"version": "0.7.11"
|
||||
},
|
||||
"tuple": {
|
||||
"dependency": "transitive",
|
||||
|
|
@ -1092,16 +883,6 @@
|
|||
"source": "hosted",
|
||||
"version": "1.4.0"
|
||||
},
|
||||
"uni_platform": {
|
||||
"dependency": "transitive",
|
||||
"description": {
|
||||
"name": "uni_platform",
|
||||
"sha256": "e02213a7ee5352212412ca026afd41d269eb00d982faa552f419ffc2debfad84",
|
||||
"url": "https://pub.dev"
|
||||
},
|
||||
"source": "hosted",
|
||||
"version": "0.1.3"
|
||||
},
|
||||
"universal_platform": {
|
||||
"dependency": "transitive",
|
||||
"description": {
|
||||
|
|
@ -1312,6 +1093,17 @@
|
|||
"source": "hosted",
|
||||
"version": "1.1.5"
|
||||
},
|
||||
"windows_gpu_recovery": {
|
||||
"dependency": "direct main",
|
||||
"description": {
|
||||
"path": ".",
|
||||
"ref": "master",
|
||||
"resolved-ref": "5d4f3101af0c1a28b80500703c0fd95844545a1e",
|
||||
"url": "https://github.com/DitriXNew/windows_gpu_recovery.git"
|
||||
},
|
||||
"source": "git",
|
||||
"version": "0.1.0"
|
||||
},
|
||||
"xdg_directories": {
|
||||
"dependency": "transitive",
|
||||
"description": {
|
||||
|
|
@ -1334,7 +1126,7 @@
|
|||
}
|
||||
},
|
||||
"sdks": {
|
||||
"dart": ">=3.9.0 <4.0.0",
|
||||
"flutter": ">=3.35.1"
|
||||
"dart": ">=3.10.0-0 <4.0.0",
|
||||
"flutter": ">=3.35.0"
|
||||
}
|
||||
}
|
||||
|
|
|
|||
46
pkgs/by-name/wo/wox/ui-flutter.nix
Normal file
46
pkgs/by-name/wo/wox/ui-flutter.nix
Normal file
|
|
@ -0,0 +1,46 @@
|
|||
{
|
||||
lib,
|
||||
flutter341,
|
||||
wox,
|
||||
autoPatchelfHook,
|
||||
keybinder3,
|
||||
xorgproto,
|
||||
libx11,
|
||||
libxtst,
|
||||
}:
|
||||
flutter341.buildFlutterApplication (finalAttrs: {
|
||||
pname = "wox-ui-flutter";
|
||||
inherit (wox)
|
||||
version
|
||||
src
|
||||
;
|
||||
|
||||
sourceRoot = "${finalAttrs.src.name}/wox.ui.flutter/wox";
|
||||
|
||||
pubspecLock = lib.importJSON ./pubspec.lock.json;
|
||||
|
||||
gitHashes.extended_text_field = "sha256-GOvaWGklfmJKRWYbVTvpZfKj9QMxxlaqrJkfDKR2T0o=";
|
||||
gitHashes.windows_gpu_recovery = "sha256-+LQV2wgbQ0ADM2KeRfgbvCHPODBBsq5XrPulXl6GWG8=";
|
||||
|
||||
nativeBuildInputs = [
|
||||
autoPatchelfHook
|
||||
];
|
||||
|
||||
buildInputs = [
|
||||
keybinder3
|
||||
xorgproto
|
||||
libx11
|
||||
libxtst
|
||||
];
|
||||
|
||||
meta = {
|
||||
inherit (wox.meta)
|
||||
description
|
||||
homepage
|
||||
mainProgram
|
||||
platforms
|
||||
license
|
||||
maintainers
|
||||
;
|
||||
};
|
||||
})
|
||||
|
|
@ -28,7 +28,7 @@ python3Packages.buildPythonApplication {
|
|||
|
||||
dependencies = with python3Packages; [
|
||||
evdev
|
||||
xlib
|
||||
python-xlib
|
||||
inotify-simple
|
||||
appdirs
|
||||
];
|
||||
|
|
|
|||
|
|
@ -19,7 +19,7 @@ python3Packages.buildPythonApplication (finalAttrs: {
|
|||
build-system = with python3Packages; [ setuptools ];
|
||||
|
||||
dependencies = with python3Packages; [
|
||||
xlib
|
||||
python-xlib
|
||||
];
|
||||
|
||||
# no tests, no python module to import, no version output to check
|
||||
|
|
|
|||
|
|
@ -31,13 +31,13 @@ let
|
|||
in
|
||||
stdenv.mkDerivation (finalAttrs: {
|
||||
pname = "lomiri-history-service";
|
||||
version = "0.6";
|
||||
version = "0.7";
|
||||
|
||||
src = fetchFromGitLab {
|
||||
owner = "ubports";
|
||||
repo = "development/core/history-service";
|
||||
rev = finalAttrs.version;
|
||||
hash = "sha256-pcTYuumywTarW+ZciwwvmmBQQH6aq4+FdVjV62VzSZU=";
|
||||
hash = "sha256-DZ6Ob0hMO3iOeNGP7tICeRMVxPl61FgHNPGk1T9HWuI=";
|
||||
};
|
||||
|
||||
outputs = [
|
||||
|
|
|
|||
|
|
@ -9,4 +9,11 @@ in
|
|||
final: _:
|
||||
builtins.mapAttrs mkRenamed {
|
||||
# A comment to prevent empty { } from collapsing into a single line
|
||||
|
||||
# NVIDIA renamed cuda_cccl to cccl in CUDA 13.3.
|
||||
# For the sake of simplicity, we updated the attrname tree-wide, accross all cudaPackages version.
|
||||
cuda_cccl = {
|
||||
path = "cccl";
|
||||
package = final.cccl;
|
||||
};
|
||||
}
|
||||
|
|
|
|||
|
|
@ -7,7 +7,7 @@
|
|||
}:
|
||||
buildRedist {
|
||||
redistName = "cuda";
|
||||
pname = "cuda_cccl";
|
||||
pname = if cudaAtLeast "13.3" then "cccl" else "cuda_cccl";
|
||||
|
||||
# Restrict header-only packages to a single output.
|
||||
# Also, when using multiple outputs (i.e., `out`, `dev`, and `include`), something isn't being patched correctly,
|
||||
|
|
@ -3,7 +3,7 @@
|
|||
backendStdenv,
|
||||
_cuda,
|
||||
cmake,
|
||||
cuda_cccl,
|
||||
cccl,
|
||||
cuda_culibos,
|
||||
cuda_cudart,
|
||||
cuda_nvcc,
|
||||
|
|
@ -71,10 +71,10 @@ backendStdenv.mkDerivation (finalAttrs: {
|
|||
"${lib.getOutput "include" cuda_cudart}/include/cooperative_groups" \
|
||||
--replace-fail \
|
||||
"\''${CUDAToolkit_BIN_DIR}/../include/nv" \
|
||||
"${lib.getOutput "include" cuda_cccl}/include/nv" \
|
||||
"${lib.getOutput "include" cccl}/include/nv" \
|
||||
--replace-fail \
|
||||
"\''${CUDAToolkit_BIN_DIR}/../include/cuda" \
|
||||
"${lib.getOutput "include" cuda_cccl}/include/cuda"
|
||||
"${lib.getOutput "include" cccl}/include/cuda"
|
||||
''
|
||||
+ lib.optionalString (samplesAtLeast "13") ''
|
||||
nixLog "patching sample 0_Introduction/matrixMul_nvrtc"
|
||||
|
|
@ -85,10 +85,10 @@ backendStdenv.mkDerivation (finalAttrs: {
|
|||
"${lib.getOutput "include" cuda_cudart}/include/cooperative_groups" \
|
||||
--replace-fail \
|
||||
"\''${CUDA_INCLUDE_DIR}/cccl/nv" \
|
||||
"${lib.getOutput "include" cuda_cccl}/include/nv" \
|
||||
"${lib.getOutput "include" cccl}/include/nv" \
|
||||
--replace-fail \
|
||||
"\''${CUDA_INCLUDE_DIR}/cccl/cuda" \
|
||||
"${lib.getOutput "include" cuda_cccl}/include/cuda"
|
||||
"${lib.getOutput "include" cccl}/include/cuda"
|
||||
''
|
||||
# These three samples give undefined references, like
|
||||
# nvlink error : Undefined reference to '__cudaCDP2Free' in 'CMakeFiles/cdpBezierTessellation.dir/BezierLineCDP.cu.o'
|
||||
|
|
@ -184,7 +184,7 @@ backendStdenv.mkDerivation (finalAttrs: {
|
|||
];
|
||||
|
||||
buildInputs = [
|
||||
cuda_cccl
|
||||
cccl
|
||||
cuda_cudart
|
||||
cuda_nvrtc
|
||||
cuda_nvtx
|
||||
|
|
|
|||
|
|
@ -4,7 +4,7 @@
|
|||
_cuda,
|
||||
addDriverRunpath,
|
||||
buildRedist,
|
||||
cuda_cccl,
|
||||
cccl,
|
||||
cuda_compat,
|
||||
cuda_crt,
|
||||
cuda_nvcc,
|
||||
|
|
@ -47,7 +47,7 @@ buildRedist (finalAttrs: {
|
|||
# Add the dependency on CCCL's include directory.
|
||||
# - nv/target
|
||||
# TODO(@connorbaker): Check that the dependency offset for this is correct.
|
||||
++ [ (lib.getOutput "include" cuda_cccl) ]
|
||||
++ [ (lib.getOutput "include" cccl) ]
|
||||
# NOTE: cuda_compat may be null or unavailable
|
||||
++ lib.optionals (cuda_compat.meta.available or false) [ cuda_compat ];
|
||||
|
||||
|
|
|
|||
|
|
@ -5,7 +5,7 @@
|
|||
setupCudaHook,
|
||||
cudaAtLeast,
|
||||
cudaOlder,
|
||||
cuda_cccl,
|
||||
cccl,
|
||||
glibc,
|
||||
lib,
|
||||
libnvvm,
|
||||
|
|
@ -120,7 +120,7 @@ buildRedist (finalAttrs: {
|
|||
substituteInPlace "''${!outputBin:?}/bin/nvcc.profile" \
|
||||
--replace-fail \
|
||||
'$(TOP)/$(_TARGET_DIR_)/include/cccl' \
|
||||
"${lib.getOutput "include" cuda_cccl}/include"
|
||||
"${lib.getOutput "include" cccl}/include"
|
||||
''
|
||||
# Unconditional patching to switch to the correct include paths.
|
||||
# NOTE: _TARGET_DIR_ appears to be used for the target architecture, which is relevant for cross-compilation.
|
||||
|
|
|
|||
Some files were not shown because too many files have changed in this diff Show more
Loading…
Add table
Add a link
Reference in a new issue